@@ -19,13 +19,13 @@
 
 #include <QFrame>
 #include <QTextStream>
+#include <QDebug>
+#include <QDoubleSpinBox>
+#include <QTemporaryFile>
+#include <QUrl>
 
-#include <kcolorbutton.h>
-#include <kdebug.h>
-#include <kmessagebox.h>
-#include <knuminput.h>
-#include <ktemporaryfile.h>
-#include <kurl.h>
+#include <KColorButton>
+#include <KMessageBox>
 
 #include "kstars.h"
 #include "kstarsdata.h"
@@ -38,66 +38,62 @@ AddCatDialogUI::AddCatDialogUI( QWidget *parent ) : QFrame( parent ) {
 }
 
 AddCatDialog::AddCatDialog( KStars *_ks )
-        : KDialog( ( QWidget* )_ks )
+        : QDialog( ( QWidget* )_ks )
 {
     QDir::setCurrent( QDir::homePath() );
     acd = new AddCatDialogUI(this);
-    setMainWidget(acd);
-    setCaption( i18n( "Import Catalog" ) );
-    setButtons( KDialog::Help|KDialog::Ok|KDialog::Cancel );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(acd);
+    setLayout(mainLayout);
+
+    setWindowTitle( xi18n( "Import Catalog" ) );
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help|QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
 
     connect( acd->DataURL->lineEdit(), SIGNAL( lostFocus() ), this, SLOT( slotShowDataFile() ) );
-    connect( acd->DataURL, SIGNAL( urlSelected( const KUrl & ) ),
+    connect( acd->DataURL, SIGNAL( urlSelected( const QUrl & ) ),
              this, SLOT( slotShowDataFile() ) );
     connect( acd->PreviewButton, SIGNAL( clicked() ), this, SLOT( slotPreviewCatalog() ) );
-    connect( this, SIGNAL( okClicked() ), this, SLOT( slotCreateCatalog() ) );
-//    connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
-    connect(this,SIGNAL(cancelClicked()),this,SLOT(slotCancel()));
-    connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
+    connect( buttonBox->button(QDialogButtonBox::Ok), SIGNAL( clicked() ), this, SLOT( slotCreateCatalog() ) );
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
+    connect(buttonBox, SIGNAL(helpRequested()), this, SLOT(slotHelp()));
 
-    acd->FieldList->addItem( i18n( "ID Number" ) );
-    acd->FieldList->addItem( i18n( "Right Ascension" ) );
-    acd->FieldList->addItem( i18n( "Declination" ) );
-    acd->FieldList->addItem( i18n( "Object Type" ) );
+    acd->FieldList->addItem( xi18n( "ID Number" ) );
+    acd->FieldList->addItem( xi18n( "Right Ascension" ) );
+    acd->FieldList->addItem( xi18n( "Declination" ) );
+    acd->FieldList->addItem( xi18n( "Object Type" ) );
 
-    acd->FieldPool->addItem( i18n( "Common Name" ) );
-    acd->FieldPool->addItem( i18n( "Magnitude" ) );
-    acd->FieldPool->addItem( i18n( "Flux" ) );
-    acd->FieldPool->addItem( i18n( "Major Axis" ) );
-    acd->FieldPool->addItem( i18n( "Minor Axis" ) );
-    acd->FieldPool->addItem( i18n( "Position Angle" ) );
-    acd->FieldPool->addItem( i18n( "Ignore" ) );
+    acd->FieldPool->addItem( xi18n( "Common Name" ) );
+    acd->FieldPool->addItem( xi18n( "Magnitude" ) );
+    acd->FieldPool->addItem( xi18n( "Flux" ) );
+    acd->FieldPool->addItem( xi18n( "Major Axis" ) );
+    acd->FieldPool->addItem( xi18n( "Minor Axis" ) );
+    acd->FieldPool->addItem( xi18n( "Position Angle" ) );
+    acd->FieldPool->addItem( xi18n( "Ignore" ) );
 }
 
 AddCatDialog::~AddCatDialog(){
 }
 
-void AddCatDialog::slotOk() {
-    //Overriding slotOk() so that custom data file can be validated before
-    //KDialog::accept() is emitted and the window is closed.
-
-    //the validation code needs to be aware of AddCatDialog members, so I will just
-    //emit the okClicked() signal, which is connected to AddCatDialog::validateFile()
-    emit okClicked();
-}
-
 void AddCatDialog::slotHelp() {
     QString message =
-        i18n( "A valid custom catalog file has one line per object, "
+        xi18n( "A valid custom catalog file has one line per object, "
               "with the following fields in each line:") + "\n\t" +
-        i18n( "1. Type identifier.  Must be one of: 0 (star), 3 (open cluster), 4 (globular cluster), "
+        xi18n( "1. Type identifier.  Must be one of: 0 (star), 3 (open cluster), 4 (globular cluster), "
               "5 (gaseous nebula), 6 (planetary nebula), 7 (supernova remnant), or 8 (galaxy)" ) + "\n\t" +
-        i18n( "2. Right Ascension (floating-point value)" ) + "\n\t" +
-        i18n( "3. Declination (floating-point value)" ) + "\n\t" +
-        i18n( "4. Magnitude (floating-point value)" ) + "\n\t" +
-        i18n( "5. Integrated Flux (floating-point value); frequency and units are set separately in the catalog file." ) + "\n\t" +
-        i18n( "6. Spectral type (if type=0); otherwise object's catalog name" ) + "\n\t" +
-        i18n( "7. Star name (if type=0); otherwise object's common name. [field 7 is optional]" ) + "\n\n" +
+        xi18n( "2. Right Ascension (floating-point value)" ) + "\n\t" +
+        xi18n( "3. Declination (floating-point value)" ) + "\n\t" +
+        xi18n( "4. Magnitude (floating-point value)" ) + "\n\t" +
+        xi18n( "5. Integrated Flux (floating-point value); frequency and units are set separately in the catalog file." ) + "\n\t" +
+        xi18n( "6. Spectral type (if type=0); otherwise object's catalog name" ) + "\n\t" +
+        xi18n( "7. Star name (if type=0); otherwise object's common name. [field 7 is optional]" ) + "\n\n" +
 
-        i18n( "The fields should be separated by whitespace.  In addition, the catalog "
+        xi18n( "The fields should be separated by whitespace.  In addition, the catalog "
               "may contain comment lines beginning with \'#\'." );
 
-    KMessageBox::information( 0, message, i18n( "Help on custom catalog file format" ) );
+    KMessageBox::information( 0, message, xi18n( "Help on custom catalog file format" ) );
 }
 
 /* Attempt to parse the catalog data file specified in the DataURL box.
@@ -138,7 +134,7 @@ bool AddCatDialog::validateDataFile() {
 }
 
 QString AddCatDialog::writeCatalogHeader() {
-    QString name = ( acd->CatalogName->text().isEmpty() ? i18n("Custom") : acd->CatalogName->text() );
+    QString name = ( acd->CatalogName->text().isEmpty() ? xi18n("Custom") : acd->CatalogName->text() );
     QString pre = ( acd->Prefix->text().isEmpty() ? "CC" : acd->Prefix->text() );
     char delimiter = ( acd->CSVButton->isChecked() ? ',' : ' ' );
 
@@ -152,27 +148,27 @@ QString AddCatDialog::writeCatalogHeader() {
     for ( int i=0; i < acd->FieldList->count(); ++i ) {
         QString f = acd->FieldList->item( i )->text();
 
-        if ( f == i18n( "ID Number" ) ) {
+        if ( f == xi18n( "ID Number" ) ) {
             h += "ID  ";
-        } else if ( f == i18n( "Right Ascension" ) ) {
+        } else if ( f == xi18n( "Right Ascension" ) ) {
             h += "RA  ";
-        } else if ( f == i18n( "Declination" ) ) {
+        } else if ( f == xi18n( "Declination" ) ) {
             h += "Dc  ";
-        } else if ( f == i18n( "Object Type" ) ) {
+        } else if ( f == xi18n( "Object Type" ) ) {
             h += "Tp  ";
-        } else if ( f == i18n( "Common Name" ) ) {
+        } else if ( f == xi18n( "Common Name" ) ) {
             h += "Nm  ";
-        } else if ( f == i18n( "Magnitude" ) ) {
+        } else if ( f == xi18n( "Magnitude" ) ) {
             h += "Mg  ";
-        } else if ( f == i18n( "Flux" ) ) {
+        } else if ( f == xi18n( "Flux" ) ) {
             h += "Flux  ";
-        } else if ( f == i18n( "Major Axis" ) ) {
+        } else if ( f == xi18n( "Major Axis" ) ) {
             h += "Mj  ";
-        } else if ( f == i18n( "Minor Axis" ) ) {
+        } else if ( f == xi18n( "Minor Axis" ) ) {
             h += "Mn  ";
-        } else if ( f == i18n( "Position Angle" ) ) {
+        } else if ( f == xi18n( "Position Angle" ) ) {
             h += "PA  ";
-        } else if ( f == i18n( "Ignore" ) ) {
+        } else if ( f == xi18n( "Ignore" ) ) {
             h += "Ig  ";
         }
     }
@@ -194,8 +190,8 @@ void AddCatDialog::slotShowDataFile() {
 
 void AddCatDialog::slotPreviewCatalog() {
     if ( validateDataFile() ) {
-        KMessageBox::informationList( 0, i18n( "Preview of %1", acd->CatalogName->text() ),
-                                      CatalogContents.split( '\n' ), i18n( "Catalog Preview" ) );
+        KMessageBox::informationList( 0, xi18n( "Preview of %1", acd->CatalogName->text() ),
+                                      CatalogContents.split( '\n' ), xi18n( "Catalog Preview" ) );
     }
 }
 
@@ -208,11 +204,11 @@ void AddCatDialog::slotCreateCatalog() {
         //Warn user if file exists!
         if ( QFile::exists( acd->CatalogURL->url().toLocalFile() ) )
         {
-            KUrl u( acd->CatalogURL->url() );
+            QUrl u( acd->CatalogURL->url() );
             int r=KMessageBox::warningContinueCancel( 0,
-                    i18n( "A file named \"%1\" already exists. "
+                    xi18n( "A file named \"%1\" already exists. "
                           "Overwrite it?", u.fileName() ),
-                    i18n( "Overwrite File?" ),
+                    xi18n( "Overwrite File?" ),
                     KStandardGuiItem::overwrite() );
 
             if(r==KMessageBox::Cancel) return;
@@ -221,8 +217,8 @@ void AddCatDialog::slotCreateCatalog() {
         QFile OutFile( acd->CatalogURL->url().toLocalFile() );
         if ( ! OutFile.open( QIODevice::WriteOnly ) ) {
             KMessageBox::sorry( 0,
-                                i18n( "Could not open the file %1 for writing.", acd->CatalogURL->url().toLocalFile() ),
-                                i18n( "Error Opening Output File" ) );
+                                xi18n( "Could not open the file %1 for writing.", acd->CatalogURL->url().toLocalFile() ),
+                                xi18n( "Error Opening Output File" ) );
         } else {
             QTextStream outStream( &OutFile );
             outStream << CatalogContents;
@@ -230,10 +226,10 @@ void AddCatDialog::slotCreateCatalog() {
 
             KStarsData::Instance()->skyComposite()->addCustomCatalog(OutFile.fileName(), 0);
 
-            emit KDialog::accept();
+            emit QDialog::accept();
             close();
         }
     }
 }
 
-#include "addcatdialog.moc"
+
