@@ -17,10 +17,12 @@
 
 #include "addlinkdialog.h"
 
-#include <kurl.h>
-#include <kmessagebox.h>
-#include <kpushbutton.h>
-#include <ktoolinvocation.h>
+#include <QPushButton>
+#include <QUrl>
+#include <QDesktopServices>
+
+#include <KMessageBox>
+#include <KToolInvocation>
 
 #include "skyobjects/skyobject.h"
 
@@ -29,30 +31,38 @@ AddLinkDialogUI::AddLinkDialogUI( QWidget *parent ) : QFrame( parent ) {
 }
 
 AddLinkDialog::AddLinkDialog( QWidget *parent, const QString &oname )
-        : KDialog( parent ),  ObjectName( oname )
+        : QDialog( parent ),  ObjectName( oname )
 {
     ald = new AddLinkDialogUI(this);
-    setMainWidget( ald );
-    setCaption( i18n( "Add Custom URL to %1", oname ) );
-    setButtons( KDialog::Ok|KDialog::Cancel );
+
+    setWindowTitle( xi18n( "Add Custom URL to %1", oname ) );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(ald);
+    setLayout(mainLayout);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
     //connect signals to slots
     connect( ald->URLButton, SIGNAL( clicked() ), this, SLOT( checkURL() ) );
     connect( ald->TypeBox, SIGNAL( clicked( int ) ), this, SLOT( changeDefaultDescription( int ) ) );
 
     ald->ImageRadio->setChecked(true);
-    ald->DescBox->setText( i18n( "Show image of " ) + ObjectName );
+    ald->DescBox->setText( xi18n( "Show image of " ) + ObjectName );
 }
 
 void AddLinkDialog::checkURL( void ) {
-    KUrl _url ( url() );
+    QUrl _url ( url() );
     if ( _url.isValid() ) {   //Is the string a valid URL?
-        KToolInvocation::invokeBrowser( _url.url() );   //If so, launch the browser to see if it's the correct document
+       QDesktopServices::openUrl(_url.url() );   //If so, launch the browser to see if it's the correct document
     } else {   //If not, print a warning message box that offers to open the browser to a search engine.
-        QString message = i18n( "The URL is not valid. Would you like to open a browser window\nto the Google search engine?" );
-        QString caption = i18n( "Invalid URL" );
-        if ( KMessageBox::warningYesNo( 0, message, caption, KGuiItem(i18n("Browse Google")), KGuiItem(i18n("Do Not Browse")) )==KMessageBox::Yes ) {
-            KToolInvocation::invokeBrowser( "http://www.google.com" );
+        QString message = xi18n( "The URL is not valid. Would you like to open a browser window\nto the Google search engine?" );
+        QString caption = xi18n( "Invalid URL" );
+        if ( KMessageBox::warningYesNo( 0, message, caption, KGuiItem(xi18n("Browse Google")), KGuiItem(xi18n("Do Not Browse")) )==KMessageBox::Yes ) {
+            QDesktopServices::openUrl( QUrl("http://www.google.com") );
         }
     }
 }
@@ -60,13 +70,13 @@ void AddLinkDialog::checkURL( void ) {
 void AddLinkDialog::changeDefaultDescription( int id ) {
     //If the user hasn't changed the default desc text, but the link type (image/webpage)
     //has been toggled, update the default desc text
-    if ( id==1 && desc().startsWith( i18n( "Show image of " ) ) ) {
-        ald->DescBox->setText( i18n( "Show webpage about " ) + ObjectName );
+    if ( id==1 && desc().startsWith( xi18n( "Show image of " ) ) ) {
+        ald->DescBox->setText( xi18n( "Show webpage about " ) + ObjectName );
     }
 
-    if ( id==0 && desc().startsWith( i18n( "Show webpage about " ) ) ) {
-        ald->DescBox->setText( i18n( "Show image of " ) + ObjectName );
+    if ( id==0 && desc().startsWith( xi18n( "Show webpage about " ) ) ) {
+        ald->DescBox->setText( xi18n( "Show image of " ) + ObjectName );
     }
 }
 
-#include "addlinkdialog.moc"
+
