@@ -24,17 +24,17 @@
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QTreeWidgetItem>
+#include <QPushButton>
+#include <QTemporaryFile>
+#include <QDebug>
+#include <QDesktopServices>
 
-#include <kstandarddirs.h>
-#include <kmessagebox.h>
-#include <kpushbutton.h>
-#include <klineedit.h>
-#include <ktoolinvocation.h>
-#include <ktemporaryfile.h>
-#include <kio/netaccess.h>
+#include <KMessageBox>
+#include <KToolInvocation>
+#include <KLocalizedString>
+#include <QStandardPaths>
 
 #include "kstars.h"
-#include "kdebug.h"
 #include "kstarsdata.h"
 #include "kstarsdatetime.h"
 #include "ksnumbers.h"
@@ -57,7 +57,7 @@
 
 #include <config-kstars.h>
 
-#ifdef HAVE_INDI_H
+#ifdef HAVE_INDI
 #include <basedevice.h>
 #include "indi/indilistener.h"
 #include "indi/indistd.h"
@@ -82,8 +82,9 @@ DetailDialog::DetailDialog(SkyObject *o, const KStarsDateTime &ut, GeoLocation *
     //Create thumbnail image
     Thumbnail = new QPixmap( 200, 200 );
 
-    setCaption( i18n( "Object Details" ) );
-    setButtons( KDialog::Close );
+    setWindowTitle( xi18n( "Object Details" ) );
+
+    setStandardButtons(QDialogButtonBox::Close);
 
     createGeneralTab();
     createPositionTab( ut, geo );
@@ -99,14 +100,14 @@ DetailDialog::~DetailDialog() {
 void DetailDialog::createGeneralTab()
 {
     Data = new DataWidget(this);
-    addPage( Data, i18n("General") );
+    addPage( Data, xi18n("General") );
 
     Data->Names->setPalette( titlePalette );
 
     //Connections
     connect( Data->ObsListButton, SIGNAL( clicked() ), this, SLOT( addToObservingList() ) );
     connect( Data->CenterButton, SIGNAL( clicked() ), this, SLOT( centerMap() ) );
-    #ifdef HAVE_INDI_H
+    #ifdef HAVE_INDI
     connect( Data->ScopeButton, SIGNAL( clicked() ), this, SLOT( centerTelescope() ) );
     #else
     Data->ScopeButton->setEnabled(false);
@@ -143,14 +144,14 @@ void DetailDialog::createGeneralTab()
             else
                 Data->Names->setText( QString( ", HD %1" ).arg( QString::number( s->getHDIndex() ) ) );
         }
-        objecttyp = s->sptype() + ' ' + i18n("star");
-        Data->Magnitude->setText( i18nc( "number in magnitudes", "%1 mag" ,
-                                         KGlobal::locale()->formatNumber( s->mag(), 2 ) ) );  //show to hundredth place
+        objecttyp = s->sptype() + ' ' + xi18n("star");
+        Data->Magnitude->setText( xi18nc( "number in magnitudes", "%1 mag" ,
+                                         QLocale().toString( s->mag(), 'f', 2 ) ) );  //show to hundredth place
 
         Data->BVLabel->setVisible( true );
         Data->BVIndex->setVisible( true );
         if( s->getBVIndex() < 30.0 )
-            Data->BVIndex->setText( QString::number( s->getBVIndex() , 'g', 2 ) );
+            Data->BVIndex->setText( QString::number( s->getBVIndex() , 'f', 2 ) );
 
         //The thumbnail image is empty, and isn't clickable for stars
         //Also, don't show the border around the Image QFrame.
@@ -159,28 +160,28 @@ void DetailDialog::createGeneralTab()
 
         //distance
         if ( s->distance() > 2000. || s->distance() < 0. )  // parallax < 0.5 mas
-            Data->Distance->setText( QString(i18nc("larger than 2000 parsecs", "> 2000 pc") ) );
+            Data->Distance->setText( QString(xi18nc("larger than 2000 parsecs", "> 2000 pc") ) );
         else if ( s->distance() > 50.0 ) //show to nearest integer
-            Data->Distance->setText( i18nc( "number in parsecs", "%1 pc" ,
-                                            KGlobal::locale()->formatNumber( s->distance(), 0 ) ) );
+            Data->Distance->setText( xi18nc( "number in parsecs", "%1 pc" ,
+                                            QLocale().toString( s->distance(), 'f', 0 ) ) );
         else if ( s->distance() > 10.0 ) //show to tenths place
-            Data->Distance->setText( i18nc( "number in parsecs", "%1 pc" ,
-                                            KGlobal::locale()->formatNumber( s->distance(), 1 ) ) );
+            Data->Distance->setText( xi18nc( "number in parsecs", "%1 pc" ,
+                                            QLocale().toString( s->distance(), 'f', 1 ) ) );
         else //show to hundredths place
-            Data->Distance->setText( i18nc( "number in parsecs", "%1 pc" ,
-                                            KGlobal::locale()->formatNumber( s->distance(), 2 ) ) );
+            Data->Distance->setText( xi18nc( "number in parsecs", "%1 pc" ,
+                                            QLocale().toString( s->distance(), 'f', 2 ) ) );
 
         //Note multiplicity/variablility in angular size label
         Data->AngSizeLabel->setText( QString() );
         Data->AngSize->setText( QString() );
         Data->AngSizeLabel->setFont( Data->AngSize->font() );
         if ( s->isMultiple() && s->isVariable() ) {
-            Data->AngSizeLabel->setText( i18nc( "the star is a multiple star", "multiple" ) + ',' );
-            Data->AngSize->setText( i18nc( "the star is a variable star", "variable" ) );
+            Data->AngSizeLabel->setText( xi18nc( "the star is a multiple star", "multiple" ) + ',' );
+            Data->AngSize->setText( xi18nc( "the star is a variable star", "variable" ) );
         } else if ( s->isMultiple() )
-            Data->AngSizeLabel->setText( i18nc( "the star is a multiple star", "multiple" ) );
+            Data->AngSizeLabel->setText( xi18nc( "the star is a multiple star", "multiple" ) );
         else if ( s->isVariable() )
-            Data->AngSizeLabel->setText( i18nc( "the star is a variable star", "variable" ) );
+            Data->AngSizeLabel->setText( xi18nc( "the star is a variable star", "variable" ) );
 
         break; //end of stars case
     case SkyObject::ASTEROID:  //[fall through to planets]
@@ -192,11 +193,11 @@ void DetailDialog::createGeneralTab()
         Data->Names->setText( ps->longname() );
         //Type is "G5 star" for Sun
         if ( ps->name() == "Sun" )
-            objecttyp = i18n("G5 star");
+            objecttyp = xi18n("G5 star");
         else if ( ps->name() == "Moon" )
             objecttyp = ps->translatedName();
-        else if ( ps->name() == i18n("Pluto") || ps->name() == "Ceres" || ps->name() == "Eris" ) // TODO: Check if Ceres / Eris have translations and i18n() them
-            objecttyp = i18n("Dwarf planet");
+        else if ( ps->name() == xi18n("Pluto") || ps->name() == "Ceres" || ps->name() == "Eris" ) // TODO: Check if Ceres / Eris have translations and i18n() them
+            objecttyp = xi18n("Dwarf planet");
         else
             objecttyp = ps->typeName();
 
@@ -204,36 +205,39 @@ void DetailDialog::createGeneralTab()
         if ( selectedObject->name() == "Moon" ) {
             Data->IllumLabel->setVisible( true );
             Data->Illumination->setVisible( true );
-            Data->Illumination->setText( QString("%1 %").arg( KGlobal::locale()->formatNumber( ((KSMoon *)selectedObject)->illum()*100., 0 ) ) );
+            Data->Illumination->setText( QString("%1 %").arg( QLocale().toString( ((KSMoon *)selectedObject)->illum()*100., 'f', 0 ) ) );
             ((KSMoon *)selectedObject)->updateMag();
         }
         
+        // JM: Shouldn't we use the calculated magnitude? Disabling the following
+        /*
         if(selectedObject->type() == SkyObject::COMET){
-            Data->Magnitude->setText( i18nc( "number in magnitudes", "%1 mag" ,
-                                             KGlobal::locale()->formatNumber( ((KSComet *)selectedObject)->getTotalMagnitudeParameter(), 2 ) ) );  //show to hundredth place
-        }
-        else{
-            Data->Magnitude->setText( i18nc( "number in magnitudes", "%1 mag" ,
-                                             KGlobal::locale()->formatNumber( ps->mag(), 2 ) ) );  //show to hundredth place
+            Data->Magnitude->setText( xi18nc( "number in magnitudes", "%1 mag" ,
+                                             QLocale().toString( ((KSComet *)selectedObject)->getTotalMagnitudeParameter(), 'f', 2 ) ) );  //show to hundredth place
+
         }
+        else{*/
+            Data->Magnitude->setText( xi18nc( "number in magnitudes", "%1 mag" ,
+                                             QLocale().toString( ps->mag(), 'f', 2 ) ) );  //show to hundredth place
+        //}
 
         //Distance from Earth.  The moon requires a unit conversion
         if ( ps->name() == "Moon" ) {
-            Data->Distance->setText( i18nc("distance in kilometers", "%1 km",
-                                           KGlobal::locale()->formatNumber( ps->rearth()*AU_KM ) ) );
+            Data->Distance->setText( xi18nc("distance in kilometers", "%1 km",
+                                           QLocale().toString( ps->rearth()*AU_KM, 'f', 2 ) ) );
         } else {
-            Data->Distance->setText( i18nc("distance in Astronomical Units", "%1 AU",
-                                           KGlobal::locale()->formatNumber( ps->rearth() ) ) );
+            Data->Distance->setText( xi18nc("distance in Astronomical Units", "%1 AU",
+                                           QLocale().toString( ps->rearth(), 'f', 3 ) ) );
         }
 
         //Angular size; moon and sun in arcmin, others in arcsec
         if ( ps->angSize() ) {
             if ( ps->name() == "Sun" || ps->name() == "Moon" )
-                Data->AngSize->setText( i18nc("angular size in arcminutes", "%1 arcmin",
-                                              KGlobal::locale()->formatNumber( ps->angSize() ) ) ); // Needn't be a plural form because sun / moon will never contract to 1 arcminute
+                Data->AngSize->setText( xi18nc("angular size in arcminutes", "%1 arcmin",
+                                              QLocale().toString( ps->angSize(), 'f', 1 ) ) ); // Needn't be a plural form because sun / moon will never contract to 1 arcminute
             else
-                Data->AngSize->setText( i18nc("angular size in arcseconds","%1 arcsec",
-                                              KGlobal::locale()->formatNumber( ps->angSize()*60.0 ) ) ); 
+                Data->AngSize->setText( xi18nc("angular size in arcseconds","%1 arcsec",
+                                              QLocale().toString( ps->angSize()*60.0 , 'f', 1 ) ));
         } else {
             Data->AngSize->setText( "--" );
         }
@@ -243,10 +247,12 @@ void DetailDialog::createGeneralTab()
     case SkyObject::SUPERNOVA:
         sup=(Supernova *)selectedObject;
 
+        objecttyp = xi18n("Supernova");
+
         Data->Names->setText(sup->name());
 
-        Data->Magnitude->setText( i18nc( "number in magnitudes", "%1 mag" ,
-                                         KGlobal::locale()->formatNumber( sup->mag(), 2 ) ) );
+        Data->Magnitude->setText( xi18nc( "number in magnitudes", "%1 mag" ,
+                                         QLocale().toString( sup->mag(), 'f', 2 ) ) );
         Data->Distance->setText( "---" );
 
         break;
@@ -283,26 +289,26 @@ void DetailDialog::createGeneralTab()
 
         if (dso->type() == SkyObject::RADIO_SOURCE)
         {
-            Data->MagLabel->setText(i18nc("integrated flux at a frequency", "Flux(%1):", dso->customCatalog()->fluxFrequency()));
-            Data->Magnitude->setText( i18nc( "integrated flux value", "%1 %2" ,
-                                             KGlobal::locale()->formatNumber( dso->flux(), 1 ), dso->customCatalog()->fluxUnit()) );  //show to tenths place
+            Data->MagLabel->setText(xi18nc("integrated flux at a frequency", "Flux(%1):", dso->customCatalog()->fluxFrequency()));
+            Data->Magnitude->setText( xi18nc( "integrated flux value", "%1 %2" ,
+                                             QLocale().toString( dso->flux(), 'f', 1 ), dso->customCatalog()->fluxUnit()) );  //show to tenths place
         }
         else if ( dso->mag() > 90.0 )
             Data->Magnitude->setText( "--" );
         else
-            Data->Magnitude->setText( i18nc( "number in magnitudes", "%1 mag" ,
-                                             KGlobal::locale()->formatNumber( dso->mag(), 1 ) ) );  //show to tenths place
+            Data->Magnitude->setText( xi18nc( "number in magnitudes", "%1 mag" ,
+                                             QLocale().toString( dso->mag(), 'f', 1 ) ) );  //show to tenths place
 
         //No distances at this point...
         Data->Distance->setText( "--" );
 
         //Only show decimal place for small angular sizes
         if ( dso->a() > 10.0 )
-            Data->AngSize->setText( i18nc("angular size in arcminutes", "%1 arcmin",
-                                          KGlobal::locale()->formatNumber(dso->a(), 0 ) ) );
+            Data->AngSize->setText( xi18nc("angular size in arcminutes", "%1 arcmin",
+                                          QLocale().toString(dso->a(), 'f', 0 ) ) );
         else if ( dso->a() )
-            Data->AngSize->setText( i18nc("angular size in arcminutes", "%1 arcmin",
-                                          KGlobal::locale()->formatNumber( dso->a(), 1 ) ) );
+            Data->AngSize->setText( xi18nc("angular size in arcminutes", "%1 arcmin",
+                                          QLocale().toString( dso->a(), 'f', 1 ) ) );
         else
             Data->AngSize->setText( "--" );
 
@@ -432,13 +438,13 @@ void DetailDialog::createGeneralTab()
             KStarsData::Instance()->skyComposite()->getConstellationBoundary()->constellationName( selectedObject ) );
     else
         Data->ObjectTypeInConstellation->setText( 
-            i18nc("%1 type of sky object (planet, asteroid etc), %2 name of a constellation", "%1 in %2", objecttyp,
+            xi18nc("%1 type of sky object (planet, asteroid etc), %2 name of a constellation", "%1 in %2", objecttyp,
                   KStarsData::Instance()->skyComposite()->getConstellationBoundary()->constellationName( selectedObject ) ) );
 }
 
 void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo ) {
     Pos = new PositionWidget(this);
-    addPage( Pos,  i18n("Position") );
+    addPage( Pos,  xi18n("Position") );
 
     Pos->CoordTitle->setPalette( titlePalette );
     Pos->RSTTitle->setPalette( titlePalette );
@@ -449,12 +455,12 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
     //because we don't want a thousands-place separator!
     QString sEpoch = QString::number( ut.epoch(), 'f', 1 );
     //Replace the decimal point with localized decimal symbol
-    sEpoch.replace( '.', KGlobal::locale()->decimalSymbol() );
+    sEpoch.replace( '.', QLocale().decimalPoint() );
     
-    kDebug() << (selectedObject->deprecess(data->updateNum(),2451545.0l)).ra0().toHMSString() << (selectedObject->deprecess(data->updateNum(),2451545.0l)).dec0().toDMSString() << endl;
-    //kDebug() << selectedObject->ra().toHMSString() << selectedObject->dec().toDMSString() << endl;
-    Pos->RALabel->setText( i18n( "RA (%1):", sEpoch ) );
-    Pos->DecLabel->setText( i18n( "Dec (%1):", sEpoch ) );
+    qDebug() << (selectedObject->deprecess(data->updateNum(),2451545.0l)).ra0().toHMSString() << (selectedObject->deprecess(data->updateNum(),2451545.0l)).dec0().toDMSString() << endl;
+    //qDebug() << selectedObject->ra().toHMSString() << selectedObject->dec().toDMSString() << endl;
+    Pos->RALabel->setText( xi18n( "RA (%1):", sEpoch ) );
+    Pos->DecLabel->setText( xi18n( "Dec (%1):", sEpoch ) );
     Pos->RA->setText( selectedObject->ra().toHMSString() );
     Pos->Dec->setText( selectedObject->dec().toDMSString() );
 
@@ -493,8 +499,8 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
     //Airmass is approximated as the secant of the zenith distance,
     //equivalent to 1./sin(Alt).  Beware of Inf at Alt=0!
     if ( selectedObject->alt().Degrees() > 0.0 )
-        Pos->Airmass->setText( KGlobal::locale()->formatNumber(
-                                   1./sin( selectedObject->alt().radians() ), 2 ) );
+        Pos->Airmass->setText( QLocale().toString(
+                                   1./sin( selectedObject->alt().radians() ), 'f', 2 ) );
     else
         Pos->Airmass->setText( "--" );
 
@@ -527,15 +533,15 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
         Pos->AzSet->setText( saz.toDMSString() );
     } else {
         if ( selectedObject->alt().Degrees() > 0.0 ) {
-            Pos->TimeRise->setText( i18n( "Circumpolar" ) );
-            Pos->TimeSet->setText( i18n( "Circumpolar" ) );
+            Pos->TimeRise->setText( xi18n( "Circumpolar" ) );
+            Pos->TimeSet->setText( xi18n( "Circumpolar" ) );
         } else {
-            Pos->TimeRise->setText( i18n( "Never rises" ) );
-            Pos->TimeSet->setText( i18n( "Never rises" ) );
+            Pos->TimeRise->setText( xi18n( "Never rises" ) );
+            Pos->TimeSet->setText( xi18n( "Never rises" ) );
         }
 
-        Pos->AzRise->setText( i18nc( "Not Applicable", "N/A" ) );
-        Pos->AzSet->setText( i18nc( "Not Applicable", "N/A" ) );
+        Pos->AzRise->setText( xi18nc( "Not Applicable", "N/A" ) );
+        Pos->AzSet->setText( xi18nc( "Not Applicable", "N/A" ) );
     }
 
     Pos->TimeTransit->setText( QString().sprintf( "%02d:%02d", tt.hour(), tt.minute() ) );
@@ -553,7 +559,7 @@ void DetailDialog::createLinksTab()
         return;
 
     Links = new LinksWidget( this );
-    addPage( Links, i18n( "Links" ) );
+    addPage( Links, xi18n( "Links" ) );
 
     Links->InfoTitle->setPalette( titlePalette );
     Links->ImagesTitle->setPalette( titlePalette );
@@ -604,11 +610,11 @@ void DetailDialog::addLink() {
 
             //Also, update the user's custom image links database
             //check for user's image-links database.  If it doesn't exist, create it.
-            file.setFileName( KStandardDirs::locateLocal( "appdata", "image_url.dat" ) ); //determine filename in local user KDE directory tree.
+            file.setFileName( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "image_url.dat" ) ; //determine filename in local user KDE directory tree.
 
             if ( !file.open( QIODevice::ReadWrite | QIODevice::Append ) ) {
-                QString message = i18n( "Custom image-links file could not be opened.\nLink cannot be recorded for future sessions." );
-                KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
+                QString message = xi18n( "Custom image-links file could not be opened.\nLink cannot be recorded for future sessions." );
+                KMessageBox::sorry( 0, message, xi18n( "Could Not Open File" ) );
         delete adialog;
                 return;
             } else {
@@ -623,11 +629,11 @@ void DetailDialog::addLink() {
             selectedObject->InfoTitle().append( adialog->desc() );
 
             //check for user's image-links database.  If it doesn't exist, create it.
-            file.setFileName( KStandardDirs::locateLocal( "appdata", "info_url.dat" ) ); //determine filename in local user KDE directory tree.
+            file.setFileName( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "info_url.dat" ) ; //determine filename in local user KDE directory tree.
 
             if ( !file.open( QIODevice::ReadWrite | QIODevice::Append ) ) {
-                QString message = i18n( "Custom information-links file could not be opened.\nLink cannot be recorded for future sessions." );
-                KMessageBox::sorry( 0, message, i18n( "Could not Open File" ) );
+                QString message = xi18n( "Custom information-links file could not be opened.\nLink cannot be recorded for future sessions." );
+                KMessageBox::sorry( 0, message, xi18n( "Could not Open File" ) );
         delete adialog;
                 return;
             } else {
@@ -647,14 +653,14 @@ void DetailDialog::createAdvancedTab()
     // Don't create an adv tab for an unnamed star or if advinterface file failed loading
     // We also don't need adv dialog for solar system objects.
     if (selectedObject->name() == QString("star") ||
-            KStarsData::Instance()->ADVtreeList.isEmpty() ||
+            KStarsData::Instance()->avdTree().isEmpty() ||
             selectedObject->type() == SkyObject::PLANET ||
             selectedObject->type() == SkyObject::COMET ||
             selectedObject->type() == SkyObject::ASTEROID )
         return;
 
     Adv = new DatabaseWidget( this );
-    addPage( Adv,  i18n( "Advanced" ) );
+    addPage( Adv,  xi18n( "Advanced" ) );
 
     connect( Adv->ADVTree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), this, SLOT(viewADVData()));
 
@@ -669,12 +675,12 @@ void DetailDialog::createLogTab()
 
     // Log Tab
     Log = new LogWidget( this );
-    addPage( Log,  i18n( "Log" ) );
+    addPage( Log,  xi18n( "Log" ) );
 
     Log->LogTitle->setPalette( titlePalette );
 
     if ( selectedObject->userLog().isEmpty() )
-        Log->UserLog->setText(i18n("Record here observation logs and/or data on %1.", selectedObject->translatedName()));
+        Log->UserLog->setText(xi18n("Record here observation logs and/or data on %1.", selectedObject->translatedName()));
     else
         Log->UserLog->setText(selectedObject->userLog());
 
@@ -702,7 +708,7 @@ void DetailDialog::viewLink()
     }
 
     if ( !URL.isEmpty() )
-        KToolInvocation::invokeBrowser(URL);
+        QDesktopServices::openUrl(URL);
 }
 
 void DetailDialog::updateLists()
@@ -739,11 +745,22 @@ void DetailDialog::editLinkDialog()
 
     if (m_CurrentLink == NULL) return;
 
-    KDialog editDialog( this );
-    editDialog.setCaption( i18n("Edit Link") );
-    editDialog.setButtons( KDialog::Ok | KDialog::Cancel );
+    QDialog editDialog( this );
+    editDialog.setWindowTitle( xi18n("Edit Link") );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+
     QFrame editFrame( &editDialog );
 
+    mainLayout->addWidget(&editFrame);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), &editDialog, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), &editDialog, SLOT(reject()));
+
+    editDialog.setLayout(mainLayout);
+
     if ( m_CurrentLink->listWidget() == Links->InfoTitleList )
     {
         row = Links->InfoTitleList->row( m_CurrentLink );
@@ -776,7 +793,7 @@ void DetailDialog::editLinkDialog()
     editNameField.setObjectName("nameedit");
     editNameField.home(false);
     editNameField.setText(currentItemTitle);
-    QLabel editLinkURL(i18n("URL:"), &editFrame);
+    QLabel editLinkURL(xi18n("URL:"), &editFrame);
     QLineEdit editLinkField(&editFrame);
     editLinkField.setObjectName("urledit");
     editLinkField.home(false);
@@ -789,7 +806,6 @@ void DetailDialog::editLinkDialog()
     editLinkLayout.addWidget(&editLinkField);
     vlay.addWidget( &editNameField );
     vlay.addLayout( &editLinkLayout );
-    editDialog.setMainWidget( &editFrame );
 
     bool go( true );
     // If user presses cancel then skip the action
@@ -830,7 +846,7 @@ void DetailDialog::removeLinkDialog()
     int type=0, row=0;
     QString currentItemURL, currentItemTitle, LineEntry, TempFileName, FileLine;
     QFile URLFile;
-    KTemporaryFile TempFile;
+    QTemporaryFile TempFile;
     TempFile.setAutoRemove(false);
     TempFile.open();
     TempFileName = TempFile.fileName();
@@ -863,7 +879,7 @@ void DetailDialog::removeLinkDialog()
     }
     else return;
 
-    if (KMessageBox::warningContinueCancel( 0, i18n("Are you sure you want to remove the %1 link?", currentItemTitle), i18n("Delete Confirmation"),KStandardGuiItem::del())!=KMessageBox::Continue)
+    if (KMessageBox::warningContinueCancel( 0, xi18n("Are you sure you want to remove the %1 link?", currentItemTitle), xi18n("Delete Confirmation"),KStandardGuiItem::del())!=KMessageBox::Continue)
         return;
 
     if (type ==0)
@@ -892,7 +908,7 @@ void DetailDialog::updateLocalDatabase(int type, const QString &search_line, con
 {
     QString TempFileName, file_line;
     QFile URLFile;
-    KTemporaryFile TempFile;
+    QTemporaryFile TempFile;
     TempFile.setAutoRemove(false);
     TempFile.open();
     QTextStream *temp_stream=NULL, *out_stream=NULL;
@@ -908,24 +924,24 @@ void DetailDialog::updateLocalDatabase(int type, const QString &search_line, con
         // Info Links
     case 0:
         // Get name for our local info_url file
-        URLFile.setFileName( KStandardDirs::locateLocal( "appdata", "info_url.dat" ) );
+        URLFile.setFileName( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "info_url.dat" ) ;
         break;
 
         // Image Links
     case 1:
         // Get name for our local info_url file
-        URLFile.setFileName( KStandardDirs::locateLocal( "appdata", "image_url.dat" ) );
+        URLFile.setFileName( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "image_url.dat" ) ;
         break;
     }
 
     // Copy URL file to temp file
-    KIO::file_copy(KUrl::fromPath(URLFile.fileName()), KUrl::fromPath(TempFileName), -1, KIO::Overwrite | KIO::HideProgressInfo );
+    KIO::file_copy(QUrl::fromLocalFile(URLFile.fileName()), QUrl::fromLocalFile(TempFileName), -1, KIO::Overwrite | KIO::HideProgressInfo );
 
 
     if ( !URLFile.open( QIODevice::WriteOnly) )
     {
-        kDebug() << "DetailDialog: Failed to open " << URLFile.fileName();
-        kDebug() << "KStars cannot save to user database";
+        qDebug() << "DetailDialog: Failed to open " << URLFile.fileName();
+        qDebug() << "KStars cannot save to user database";
         return;
     }
 
@@ -962,7 +978,7 @@ void DetailDialog::populateADVTree()
 
     // We populate the tree iterativley, keeping track of parents as we go
     // This solution is more efficient than the previous recursion algorithm.
-    foreach (ADVTreeData *item, KStarsData::Instance()->ADVtreeList)
+    foreach (ADVTreeData *item, KStarsData::Instance()->avdTree())
     {
 
         switch (item->Type)
@@ -998,13 +1014,13 @@ void  DetailDialog::viewADVData()
     //If the item has children or is invalid, do nothing
     if ( !current || current->childCount()>0 )  return;
 
-    foreach (ADVTreeData *item, KStarsData::Instance()->ADVtreeList)
+    foreach (ADVTreeData *item, KStarsData::Instance()->avdTree())
     {
         if (item->Name == current->text(0))
         {
             link = item->Link;
             link = parseADVData(link);
-            KToolInvocation::invokeBrowser(link);
+            QDesktopServices::openUrl(link);
             return;
         }
     }
@@ -1058,23 +1074,22 @@ void DetailDialog::saveLogData() {
 }
 
 void DetailDialog::addToObservingList() {
-    KStars::Instance()->observingList()->slotAddObject( selectedObject );
+    KStarsData::Instance()->observingList()->slotAddObject( selectedObject );
 }
 
-void DetailDialog::centerMap() {
-    SkyMap* map = KStars::Instance()->map();
-    map->setClickedObject( selectedObject );
-    map->slotCenter();
+void DetailDialog::centerMap()
+{
+    SkyMap::Instance()->setClickedObject( selectedObject );
+    SkyMap::Instance()->slotCenter();
 }
 
 void DetailDialog::centerTelescope()
 {
-
-#ifdef HAVE_INDI_H
+#ifdef HAVE_INDI
 
     if (INDIListener::Instance()->size() == 0)
     {
-        KMessageBox::sorry(0, i18n("KStars did not find any active telescopes."));
+        KMessageBox::sorry(0, xi18n("KStars did not find any active telescopes."));
         return;
     }
 
@@ -1090,7 +1105,7 @@ void DetailDialog::centerTelescope()
 
         if (bd->isConnected() == false)
         {
-            KMessageBox::error(0, i18n("Telescope %1 is offline. Please connect and retry again.", gd->getDeviceName()));
+            KMessageBox::error(0, xi18n("Telescope %1 is offline. Please connect and retry again.", gd->getDeviceName()));
             return;
         }
 
@@ -1104,7 +1119,7 @@ void DetailDialog::centerTelescope()
 
     }
 
-    KMessageBox::sorry(0, i18n("KStars did not find any active telescopes."));
+    KMessageBox::sorry(0, xi18n("KStars did not find any active telescopes."));
 
 #endif
 }
@@ -1142,15 +1157,21 @@ void DetailDialog::updateThumbnail() {
     QPointer<ThumbnailPicker> tp = new ThumbnailPicker( selectedObject, *Thumbnail, this );
 
     if ( tp->exec() == QDialog::Accepted ) {
-        QString fname = KStandardDirs::locateLocal( "appdata", "thumb-" + selectedObject->name().toLower().remove( ' ' ) + ".png" );
+        QString fname = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "thumb-" + selectedObject->name().toLower().remove( ' ' ) + ".png" ;
 
         Data->Image->setPixmap( *(tp->image()) );
 
         //If a real image was set, save it.
         //If the image was unset, delete the old image on disk.
-        if ( tp->imageFound() ) {
-            Data->Image->pixmap()->save( fname, "PNG" );
-            *Thumbnail = *(Data->Image->pixmap());
+        if ( tp->imageFound() )
+        {
+            bool rc = Data->Image->pixmap()->save( fname, "PNG" );
+            if (rc == false)
+            {
+                KMessageBox::error(0, xi18n("Error: Unable to save image to %1", fname), xi18n("Save Thumbnail"));
+            }
+            else
+                *Thumbnail = *(Data->Image->pixmap());
         } else {
             QFile f;
             f.setFileName( fname );
@@ -1193,4 +1214,4 @@ LogWidget::LogWidget( QWidget *p ) : QFrame( p )
     setupUi( this );
 }
 
-#include "detaildialog.moc"
+
