@@ -18,9 +18,9 @@
 
 #include "timedialog.h"
 
-#include <klocale.h>
-#include <kpushbutton.h>
-#include <kdatepicker.h>
+#include <KLocalizedString>
+#include <QPushButton>
+#include <KDatePicker>
 
 #include <QFrame>
 #include <QVBoxLayout>
@@ -34,17 +34,25 @@
 #include "geolocation.h"
 
 TimeDialog::TimeDialog( const KStarsDateTime &now, GeoLocation *_geo, QWidget *parent, bool UTCFrame )
-        : KDialog( parent ), geo( _geo )
+        : QDialog( parent ), geo( _geo )
 {
     UTCNow = UTCFrame;
 
     QFrame *page = new QFrame(this);
-    setMainWidget( page );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(page);
+    setLayout(mainLayout);
+
     if( UTCNow )
-        setCaption( i18nc( "set clock to a new time", "Set UTC Time" ) );
+        setWindowTitle( xi18nc( "set clock to a new time", "Set UTC Time" ) );
     else
-        setCaption( i18nc( "set clock to a new time", "Set Time" ) );
-    setButtons( KDialog::Ok|KDialog::Cancel );
+        setWindowTitle( xi18nc( "set clock to a new time", "Set Time" ) );
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
     vlay = new QVBoxLayout( page );
     vlay->setMargin( 2 );
@@ -54,9 +62,9 @@ TimeDialog::TimeDialog( const KStarsDateTime &now, GeoLocation *_geo, QWidget *p
 
     dPicker = new KDatePicker( now.date(), page );
     tEdit = new QTimeEdit( now.time(), page );
-    NowButton = new KPushButton( page );
+    NowButton = new QPushButton( page );
     NowButton->setObjectName( "NowButton" );
-    NowButton->setText( UTCNow ? i18n( "UTC Now"  ) : i18n( "Now"  ) );
+    NowButton->setText( UTCNow ? xi18n( "UTC Now"  ) : xi18n( "Now"  ) );
 
     vlay->addWidget( dPicker, 0, 0 );
     vlay->addLayout( hlay, 0 );
@@ -66,8 +74,6 @@ TimeDialog::TimeDialog( const KStarsDateTime &now, GeoLocation *_geo, QWidget *p
 
     vlay->activate();
 
-    QObject::connect( this, SIGNAL( okClicked() ), this, SLOT( accept() ));
-    QObject::connect( this, SIGNAL( cancelClicked() ), this, SLOT( reject() ));
     QObject::connect( NowButton, SIGNAL( clicked() ), this, SLOT( setNow() ));
 }
 
@@ -88,7 +94,7 @@ void TimeDialog::keyReleaseEvent( QKeyEvent *kev ) {
 
 void TimeDialog::setNow( void )
 {
-    KStarsDateTime dt( KStarsDateTime::currentDateTime( KDateTime::Spec::UTC() ) );
+    KStarsDateTime dt( KStarsDateTime::currentDateTimeUtc() );
     if ( ! UTCNow )
         dt = geo->UTtoLT( dt );
 
@@ -108,4 +114,4 @@ KStarsDateTime TimeDialog::selectedDateTime( void ) {
     return KStarsDateTime( selectedDate(), selectedTime() );
 }
 
-#include "timedialog.moc"
+
