@@ -33,15 +33,15 @@
 #include <QDateTime>
 #include <QPainter>
 #include <QPixmap>
+#include <QDebug>
+#include <QAction>
+#include <QStatusBar>
+#include <QFileDialog>
+#include <QWheelEvent>
 
-#include <KDebug>
-#include <KLocale>
-#include <KAction>
 #include <KActionCollection>
-#include <KStatusBar>
-#include <KProgressDialog>
 #include <KMessageBox>
-#include <KFileDialog>
+#include <KLocalizedString>
 
 #include "ksutils.h"
 
@@ -51,6 +51,8 @@
 #define ZOOM_LOW_INCR	10
 #define ZOOM_HIGH_INCR	50
 
+#define DECAY_CONSTANT  -0.04
+
 //#define FITS_DEBUG
 
 FITSLabel::FITSLabel(FITSView *img, QWidget *parent) : QLabel(parent)
@@ -71,7 +73,7 @@ FITSLabel::~FITSLabel() {}
 void FITSLabel::mouseMoveEvent(QMouseEvent *e)
 {
     double x,y;
-    FITSImage *image_data = image->getImageData();
+    FITSData *image_data = image->getImageData();
 
     float *buffer = image_data->getImageBuffer();
 
@@ -84,16 +86,16 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
     x = KSUtils::clamp(x, 1.0, width);
     y = KSUtils::clamp(y, 1.0, height);
 
-    emit newStatus(QString("%1 , %2").arg( (int)x ).arg( (int)y ), FITS_POSITION);
+    emit newStatus(QString("X:%1 Y:%2").arg( (int)x ).arg( (int)y ), FITS_POSITION);
 
     // Range is 0 to dim-1 when accessing array
     x -= 1;
     y -= 1;
 
     if (image_data->getBPP() == -32 || image_data->getBPP() == 32)
-        emit newStatus(KGlobal::locale()->formatNumber( buffer[(int) (y * width + x)], 5), FITS_VALUE);
+        emit newStatus(QLocale().toString(buffer[(int) (y * width + x)], 'f', 4), FITS_VALUE);
     else
-        emit newStatus(KGlobal::locale()->formatNumber( buffer[(int) (y * width + x)]), FITS_VALUE);
+        emit newStatus(QLocale().toString(buffer[(int) (y * width + x)], 'f', 2), FITS_VALUE);
 
 
     if (image_data->hasWCS())
@@ -130,13 +132,14 @@ void FITSLabel::mousePressEvent(QMouseEvent *e)
 
 }
 
-FITSView::FITSView(QWidget * parent, FITSMode fitsMode) : QScrollArea(parent) , zoomFactor(1.2)
+FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) : QScrollArea(parent) , zoomFactor(1.2)
 {
     image_frame = new FITSLabel(this);
     image_data  = NULL;
     display_image = NULL;
     firstLoad = true;
-
+    gammaValue=0;
+    filter = filterType;
     mode = fitsMode;
 
     setBackgroundRole(QPalette::Dark);
@@ -144,10 +147,10 @@ FITSView::FITSView(QWidget * parent, FITSMode fitsMode) : QScrollArea(parent) ,
     guide_x = guide_y = guide_box = -1;
 
     currentZoom = 0.0;
-    markStars = false;
+    markStars = false;    
 
     connect(image_frame, SIGNAL(newStatus(QString,FITSBar)), this, SIGNAL(newStatus(QString,FITSBar)));
-    connect(image_frame, SIGNAL(pointSelected(int,int)), this, SLOT(processPointSelection(int,int)));
+    connect(image_frame, SIGNAL(pointSelected(int,int)), this, SLOT(processPointSelection(int,int)));    
 
     image_frame->setMouseTracking(true);
 
@@ -160,24 +163,37 @@ FITSView::FITSView(QWidget * parent, FITSMode fitsMode) : QScrollArea(parent) ,
 
 FITSView::~FITSView()
 {
-    delete(display_image);
+    delete(image_frame);
     delete(image_data);
+    delete(display_image);    
 }
 
 bool FITSView::loadFITS ( const QString &inFilename )
 {
     QProgressDialog fitsProg;
+    bool setBayerParams=false;
 
+    BayerParams param;
+    if (image_data && image_data->hasDebayer())
+    {
+        setBayerParams=true;
+        image_data->getBayerParams(&param);
+    }
 
     delete (image_data);
     image_data = NULL;
 
-    image_data = new FITSImage(mode);
+    image_data = new FITSData(mode);
+
+    if (setBayerParams)
+        image_data->setBayerParams(&param);
 
     if (image_data->loadFITS(inFilename, &fitsProg) == false)
         return false;
 
-    image_data->getSize(&currentWidth, &currentHeight);
+    emit debayerToggled(image_data->hasDebayer());
+
+    image_data->getDimensions(&currentWidth, &currentHeight);
 
     image_width  = currentWidth;
     image_height = currentHeight;
@@ -186,14 +202,17 @@ bool FITSView::loadFITS ( const QString &inFilename )
 
     hasWCS = image_data->hasWCS();
 
-    delete (display_image);
-    display_image = NULL;
+    maxPixel = image_data->getMax();
+    minPixel = image_data->getMin();
 
-    display_image = new QImage(image_width, image_height, QImage::Format_Indexed8);
+    if (gammaValue != 0 && (filter== FITS_NONE || filter >= FITS_FLIP_H))
+    {
+        double maxGammaPixel = maxPixel* (100 * exp(DECAY_CONSTANT * gammaValue))/100.0;
+        // If calculated maxPixel after gamma is different from image data max pixel, then we apply filter immediately.
+        image_data->applyFilter(FITS_LINEAR, NULL, minPixel, maxGammaPixel);
+    }
 
-    display_image->setNumColors(256);
-    for (int i=0; i < 256; i++)
-        display_image->setColor(i, qRgb(i,i,i));
+    initDisplayImage();
 
     // Rescale to fits window
     if (firstLoad)
@@ -227,41 +246,89 @@ int FITSView::saveFITS( const QString &newFilename )
 
 int FITSView::rescale(FITSZoom type)
 {
-    float val=0;
+    double val=0;
     double bscale, bzero;
     double min, max;
-
+    unsigned int size = image_data->getSize();
     image_data->getMinMax(&min, &max);
-    float *image_buffer = image_data->getImageBuffer();
+
+    calculateMaxPixel(min, max);
+
+    min = minPixel;
+    max = maxGammaPixel;
 
     if (min == max)
     {
-        // For focus and guide, we silenty ignore saturation error.
-        if (mode == FITS_FOCUS || mode == FITS_GUIDE)
-            qDebug() << "FITS image is saturated and cannot be displayed." << endl;
-        else
-            KMessageBox::error(0, i18n("FITS image is saturated and cannot be displayed."), i18n("FITS Open"));
-        return -1;
+        display_image->fill(Qt::white);
+        emit newStatus(xi18n("Image is saturated!"), FITS_MESSAGE);
     }
-
-
-    bscale = 255. / (max - min);
-    bzero  = (-min) * (255. / (max - min));
-
-    image_frame->setScaledContents(true);
-    currentWidth  = display_image->width();
-    currentHeight = display_image->height();
-
-    /* Fill in pixel values using indexed map, linear scale */
-    for (int j = 0; j < image_height; j++)
+    else
     {
-        unsigned char *scanLine = display_image->scanLine(j);
+        bscale = 255. / (max - min);
+        bzero  = (-min) * (255. / (max - min));
 
-        for (int i = 0; i < image_width; i++)
-        {
-            val = image_buffer[j * image_width + i];
-            scanLine[i]= (val * bscale + bzero);
+        if (image_height != image_data->getHeight() || image_width != image_data->getWidth())
+        {            
+            image_width  = image_data->getWidth();
+            image_height = image_data->getHeight();
+
+            initDisplayImage();
+
+            if (isVisible())
+                emit newStatus(QString("%1x%2").arg(image_width).arg(image_height), FITS_RESOLUTION);
         }
+
+        image_frame->setScaledContents(true);
+        currentWidth  = display_image->width();
+        currentHeight = display_image->height();
+
+        float *image_buffer = image_data->getImageBuffer();
+
+        if (image_data->getNumOfChannels() == 1)
+        {
+            /* Fill in pixel values using indexed map, linear scale */
+            for (int j = 0; j < image_height; j++)
+            {
+                unsigned char *scanLine = display_image->scanLine(j);
+
+                for (int i = 0; i < image_width; i++)
+                {
+                    val = image_buffer[j * image_width + i];
+                    if (gammaValue > 0)
+                        val = qBound(minPixel, val, maxGammaPixel);
+                    scanLine[i]= (val * bscale + bzero);
+                }
+            }
+        }
+        else
+        {
+            double rval=0,gval=0,bval=0;
+            QRgb value;
+            /* Fill in pixel values using indexed map, linear scale */
+            for (int j = 0; j < image_height; j++)
+            {
+                //QRgb *scanLine = static_cast<QRgb*>(display_image->scanLine(j));
+
+                for (int i = 0; i < image_width; i++)
+                {
+                    rval = image_buffer[j * image_width + i];
+                    gval = image_buffer[j * image_width + i + size];
+                    bval = image_buffer[j * image_width + i + size * 2];
+                    if (gammaValue > 0)
+                    {
+                        rval = qBound(minPixel, rval, maxGammaPixel);
+                        gval = qBound(minPixel, gval, maxGammaPixel);
+                        gval = qBound(minPixel, gval, maxGammaPixel);
+                    }
+
+                    value = qRgb(rval* bscale + bzero, gval* bscale + bzero, bval* bscale + bzero);
+
+                    display_image->setPixel(i, j, value);
+                }
+            }
+
+        }
+
     }
 
     switch (type)
@@ -331,7 +398,10 @@ void FITSView::ZoomIn()
 
     emit actionUpdated("view_zoom_out", true);
     if (currentZoom >= ZOOM_MAX)
+    {
+        currentZoom = ZOOM_MAX;
         emit actionUpdated("view_zoom_in", false);
+    }
 
     currentWidth  = image_width * (currentZoom / ZOOM_DEFAULT);
     currentHeight = image_height * (currentZoom / ZOOM_DEFAULT);
@@ -351,7 +421,10 @@ void FITSView::ZoomOut()
         currentZoom -= ZOOM_HIGH_INCR;
 
     if (currentZoom <= ZOOM_MIN)
+    {
+        currentZoom = ZOOM_MIN;
         emit actionUpdated("view_zoom_out", false);
+    }
 
     emit actionUpdated("view_zoom_in", true);
 
@@ -489,9 +562,13 @@ void FITSView::toggleStars(bool enable)
 
      if (markStars == true)
      {
+       QApplication::setOverrideCursor(Qt::WaitCursor);
+       emit newStatus(xi18n("Finding stars..."), FITS_MESSAGE);
+       qApp->processEvents();
        int count = image_data->findStars();
        if (count >= 0 && isVisible())
-               emit newStatus(i18np("1 star detected.", "%1 stars detected.", count), FITS_MESSAGE);
+               emit newStatus(xi18np("1 star detected.", "%1 stars detected.", count), FITS_MESSAGE);
+       QApplication::restoreOverrideCursor();
      }
 }
 
@@ -505,5 +582,67 @@ void FITSView::processPointSelection(int x, int y)
     setGuideSquare(x,y);
     emit guideStarSelected(x,y);
 }
+int FITSView::getGammaValue() const
+{
+    return gammaValue;
+}
+
+void FITSView::setGammaValue(int value)
+{
+    if (value == gammaValue)
+        return;
+
+    gammaValue = value;
+
+    calculateMaxPixel(minPixel, maxPixel);
+
+    // If calculated maxPixel after gamma is different from image data max pixel, then we apply filter immediately.
+    //image_data->applyFilter(FITS_LINEAR, NULL, minPixel, maxGammaPixel);
+    qApp->processEvents();
+    rescale(ZOOM_KEEP_LEVEL);
+    qApp->processEvents();
+    updateFrame();
+
+}
+
+void FITSView::calculateMaxPixel(double min, double max)
+{
+    minPixel=min;
+    maxPixel=max;
+
+    if (gammaValue == 0)
+        maxGammaPixel = maxPixel;
+    else
+        maxGammaPixel = maxPixel* (100 * exp(DECAY_CONSTANT * gammaValue))/100.0;
+}
+
+
+void FITSView::wheelEvent(QWheelEvent* event)
+{
+    if (event->angleDelta().y() > 0)
+        ZoomIn();
+    else
+        ZoomOut();
+
+    event->accept();
+}
+
+void FITSView::initDisplayImage()
+{
+    delete (display_image);
+    display_image = NULL;
+
+    if (image_data->getNumOfChannels() == 1)
+    {
+        display_image = new QImage(image_width, image_height, QImage::Format_Indexed8);
+
+        display_image->setColorCount(256);
+        for (int i=0; i < 256; i++)
+            display_image->setColor(i, qRgb(i,i,i));
+    }
+    else
+    {
+        display_image = new QImage(image_width, image_height, QImage::Format_RGB32);
+    }
+}
 
-#include "fitsview.moc"
