@@ -15,7 +15,13 @@
 namespace ISD
 {
 
-
+/**
+ * @class Telescope
+ * device handle controlling telescope. It can slew and sync to a specific sky point and supports all standard propreties with INDI
+ * telescope device.
+ *
+ * @author Jasem Mutlaq
+ */
 class Telescope : public DeviceDecorator
 {
     Q_OBJECT
@@ -24,6 +30,9 @@ public:
     Telescope(GDInterface *iPtr);
     ~Telescope();
 
+    typedef enum { MOTION_NORTH, MOTION_SOUTH } TelescopeMotionNS;
+    typedef enum { MOTION_WEST, MOTION_EAST } TelescopeMotionWE;
+
     void registerProperty(INDI::Property *prop);
     void processSwitch(ISwitchVectorProperty *svp);
     void processText(ITextVectorProperty* tvp);
@@ -36,8 +45,8 @@ public:
     bool Slew(double ra, double dec);
     bool Sync(SkyPoint *ScopeTarget);
     bool Sync(double ra, double dec);
-    bool Abort();
-    bool Park();
+    bool MoveNS(TelescopeMotionNS dir);
+    bool MoveWE(TelescopeMotionWE dir);    
     bool canGuide();
     bool canSync();
     bool canPark();
@@ -49,12 +58,12 @@ public:
 protected:
     bool sendCoords(SkyPoint *ScopeTarget);
 
-
 public slots:
     virtual bool runCommand(int command, void *ptr=NULL);
+    bool Abort();
+    bool Park();
 
 private:
-
     SkyPoint currentCoord;
 
 };
