@@ -13,30 +13,28 @@
 #include "indistd.h"
 #include "Options.h"
 
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kpushbutton.h>
-#include <kiconloader.h>
-#include <ktemporaryfile.h>
-#include <kio/netaccess.h>
-#include <kfiledialog.h>
-#include <kcombobox.h>
-#include <kurl.h>
+#include <KMessageBox>
+#include <KLocalizedString>
 
+#include <QLocale>
+#include <QDebug>
+#include <QPushButton>
+#include <QFileDialog>
 #include <QRgb>
-#include <qsocketnotifier.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qstringlist.h>
-#include <qdir.h>
-#include <qlayout.h>
+#include <QSocketNotifier>
+#include <QImage>
+#include <QPainter>
+#include <QStringList>
+#include <QDir>
+#include <QLayout>
 #include <QResizeEvent>
 #include <QPaintEvent>
 #include <QCloseEvent>
 #include <QByteArray>
 #include <QImageWriter>
 #include <QImageReader>
+#include <QIcon>
+#include <QTemporaryFile>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -51,9 +49,9 @@ StreamWG::StreamWG(QWidget * parent) : QWidget(parent)
 
     streamFrame      = new VideoWG(videoFrame);
 
-    playPix    = KIcon( "media-playback-start" );
-    pausePix   = KIcon( "media-playback-pause" );
-    capturePix = KIcon( "media-record" );
+    playPix    = QIcon::fromTheme( "media-playback-start" );
+    pausePix   = QIcon::fromTheme( "media-playback-pause" );
+    capturePix = QIcon::fromTheme( "media-record" );
 
     foreach (const QByteArray &format, QImageWriter::supportedImageFormats())
     imgFormatCombo->addItem(QString(format));
@@ -141,7 +139,7 @@ void StreamWG::newFrame(IBLOB *bp)
     else if (rc == false)
     {
         close();
-        KMessageBox::error(0, i18n("Unable to load video stream."));
+        KMessageBox::error(0, xi18n("Unable to load video stream."));
     }
 }
 
@@ -149,22 +147,22 @@ void StreamWG::captureImage()
 {
     QString fname;
     QString fmt;
-    KUrl currentFileURL;
+    QUrl currentFileURL;
     QString currentDir = Options::fitsDir();
-    KTemporaryFile tmpfile;
+    QTemporaryFile tmpfile;
     tmpfile.open();
 
     fmt = imgFormatCombo->currentText();
 
-    currentFileURL = KFileDialog::getSaveUrl( currentDir, fmt );
+    currentFileURL = QFileDialog::getSaveFileUrl(0, xi18n("Save Image"), currentDir, fmt );
 
     if (currentFileURL.isEmpty()) return;
 
     if ( currentFileURL.isValid() )
     {
-        currentDir = currentFileURL.directory();
+        //currentDir = currentFileURL.path();
 
-        if ( currentFileURL.isLocalFile() )
+        /*if ( currentFileURL.isLocalFile() )
             fname = currentFileURL.path();
         else
             fname = tmpfile.fileName();
@@ -173,27 +171,27 @@ void StreamWG::captureImage()
         {
             fname += '.';
             fname += fmt.toLower();
-        }
+        }*/
 
-        streamFrame->kPix.save(fname, fmt.toAscii());
+        streamFrame->kPix.save(currentFileURL.path(), fmt.toLatin1());
 
         //set rwx for owner, rx for group, rx for other
-        chmod( fname.toAscii(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH );
+        /*chmod( fname.toLatin1(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH );
 
         if ( tmpfile.fileName() == fname )
         { //need to upload to remote location
 
             if ( ! KIO::NetAccess::upload( tmpfile.fileName(), currentFileURL, (QWidget*) 0 ) )
             {
-                QString message = i18n( "Could not upload image to remote location: %1", currentFileURL.prettyUrl() );
-                KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
+                QString message = xi18n( "Could not upload image to remote location: %1", currentFileURL.prettyUrl() );
+                KMessageBox::sorry( 0, message, xi18n( "Could not upload file" ) );
             }
-        }
+        }*/
     }
     else
     {
-        QString message = i18n( "Invalid URL: %1", currentFileURL.url() );
-        KMessageBox::sorry( 0, message, i18n( "Invalid URL" ) );
+        QString message = xi18n( "Invalid URL: %1", currentFileURL.url() );
+        KMessageBox::sorry( 0, message, xi18n( "Invalid URL" ) );
     }
 
 }
@@ -223,8 +221,8 @@ bool VideoWG::newFrame(IBLOB *bp)
     format.remove("stream_");
     bool rc = false;
 
-    int w = *((double *) bp->aux0);
-    int h = *((double *) bp->aux1);
+    int w = *((int *) bp->aux0);
+    int h = *((int *) bp->aux1);
 
     if (QImageReader::supportedImageFormats().contains(format.toLatin1()))
            rc = streamImage->loadFromData(static_cast<uchar *>(bp->blob), bp->size);
@@ -270,4 +268,4 @@ int VideoWG::imageHeight()
     return streamImage->height();
 }
 
-#include "streamwg.moc"
+
