@@ -20,10 +20,10 @@
 #include <QList>
 #include <QListWidgetItem>
 #include <QTextStream>
+#include <QFileDialog>
 
-#include <kfiledialog.h>
-#include <kactioncollection.h>
-#include <kconfigdialog.h>
+#include <KActionCollection>
+#include <KConfigDialog>
 
 #include "Options.h"
 #include "kstars.h"
@@ -90,9 +90,9 @@ OpsCatalog::OpsCatalog( KStars *_ks )
     connect( kcfg_ShowStars, SIGNAL( toggled(bool) ), SLOT( slotStarWidgets(bool) ) );
     connect( kcfg_ShowDeepSky, SIGNAL( toggled(bool) ), SLOT( slotDeepSkyWidgets(bool) ) );
     connect( kcfg_ShowDeepSkyNames, SIGNAL( toggled(bool) ), kcfg_DeepSkyLongLabels, SLOT( setEnabled(bool) ) );
-    connect( m_ConfigDialog, SIGNAL( applyClicked() ), SLOT( slotApply() ) );
-    connect( m_ConfigDialog, SIGNAL( okClicked() ), SLOT( slotApply() ) );
-    connect( m_ConfigDialog, SIGNAL( cancelClicked() ), SLOT( slotCancel() ) );
+    connect( m_ConfigDialog->button(QDialogButtonBox::Apply), SIGNAL( clicked() ), SLOT( slotApply() ) );
+    connect( m_ConfigDialog->button(QDialogButtonBox::Ok), SIGNAL( clicked() ), SLOT( slotApply() ) );
+    connect( m_ConfigDialog->button(QDialogButtonBox::Cancel), SIGNAL( clicked() ), SLOT( slotCancel() ) );
 }
 
 //empty destructor
@@ -128,7 +128,7 @@ void OpsCatalog::updateCustomCatalogs() {
         }
     }
 
-    m_ConfigDialog->enableButtonApply( false );
+    m_ConfigDialog->button(QDialogButtonBox::Apply)->setEnabled(false);
 }
 
 
@@ -159,12 +159,13 @@ void OpsCatalog::slotAddCatalog() {
 
 void OpsCatalog::slotLoadCatalog() {
     //Get the filename from the user
-    QString filename = KFileDialog::getOpenFileName( QDir::homePath(), "*");
+    QString filename = QFileDialog::getOpenFileName(0, QString(),  QDir::homePath(), "*");
     if ( ! filename.isEmpty() ) {
         ksw->data()->catalogdb()->AddCatalogContents(filename);
         refreshCatalogList();
     }
-    m_ConfigDialog->enableButtonApply( false );
+
+    m_ConfigDialog->button(QDialogButtonBox::Apply)->setEnabled(false);
 }
 
 
@@ -176,9 +177,9 @@ void OpsCatalog::refreshCatalogList() {
 
 void OpsCatalog::slotRemoveCatalog() {
     if (KMessageBox::warningYesNo(0,
-                     i18n("The selected database will be removed. "
+                     xi18n("The selected database will be removed. "
                            "This action cannot be reversed! Delete Catalog?"),
-                          i18n("Delete Catalog?") )
+                          xi18n("Delete Catalog?") )
             == KMessageBox::No) {
             KMessageBox::information(0, "Catalog deletion cancelled.");
             return;
@@ -198,7 +199,7 @@ void OpsCatalog::slotRemoveCatalog() {
     QListWidgetItem *todelete = CatalogList->takeItem( CatalogList->row( CatalogList->currentItem() ) );
     delete todelete;
     refreshCatalogList();
-    m_ConfigDialog->enableButtonApply( false );
+    m_ConfigDialog->button(QDialogButtonBox::Apply)->setEnabled(false);
     KStars::Instance()->data()->skyComposite()->reloadDeepSky();
 }
 
@@ -304,19 +305,19 @@ void OpsCatalog::slotDeepSkyWidgets(bool on) {
 
 
 void OpsCatalog::populateInbuiltCatalogs() {
-    showIC = new QListWidgetItem( i18n( "Index Catalog (IC)" ), CatalogList );
+    showIC = new QListWidgetItem( xi18n( "Index Catalog (IC)" ), CatalogList );
     showIC->setFlags( Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled );
     showIC->setCheckState( Options::showIC() ?  Qt::Checked : Qt::Unchecked );
 
-    showNGC = new QListWidgetItem( i18n( "New General Catalog (NGC)" ), CatalogList );
+    showNGC = new QListWidgetItem( xi18n( "New General Catalog (NGC)" ), CatalogList );
     showNGC->setFlags( Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled );
     showNGC->setCheckState( Options::showNGC() ?  Qt::Checked : Qt::Unchecked );
 
-    showMessImages = new QListWidgetItem( i18n( "Messier Catalog (images)" ), CatalogList );
+    showMessImages = new QListWidgetItem( xi18n( "Messier Catalog (images)" ), CatalogList );
     showMessImages->setFlags( Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled );
     showMessImages->setCheckState( Options::showMessierImages()  ?  Qt::Checked : Qt::Unchecked );
 
-    showMessier = new QListWidgetItem( i18n( "Messier Catalog (symbols)" ), CatalogList );
+    showMessier = new QListWidgetItem( xi18n( "Messier Catalog (symbols)" ), CatalogList );
     showMessier->setFlags( Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled );
     showMessier->setCheckState( Options::showMessier() ?  Qt::Checked : Qt::Unchecked );
 
@@ -347,4 +348,4 @@ void OpsCatalog::populateCustomCatalogs() {
 }
 
 
-#include "opscatalog.moc"
+
