@@ -71,7 +71,7 @@ public:
     /**
      *@return true if visibility Option is set for this catalog
      *@note this is complicated for custom catalogs, because
-     *Option::showCatalog() returns a QList<int>, not a bool.
+     *Options::showCatalog() returns a QList<int>, not a bool.
      *This function extracts the correct visibility value and
      *returns the appropriate bool value
      */
@@ -82,7 +82,7 @@ private:
     /** @short Load data into custom catalog */
     void loadData();
 
-    /**@short Read data for existing custom catalogs from disk
+    /** @short Read data for existing custom catalogs from disk
      * @return true if catalog data was successfully read
      */
     bool readCustomCatalogs();
