@@ -33,17 +33,15 @@
 #include <QApplication>
 #include <QGraphicsScene>
 #include <QInputDialog>
+#include <QIcon>
+#include <QDesktopServices>
 
-#include <kactioncollection.h>
-#include <kconfig.h>
-#include <kiconloader.h>
-#include <kstatusbar.h>
-#include <kmessagebox.h>
-#include <kaction.h>
-#include <kstandarddirs.h>
-#include <ktoolbar.h>
-#include <ktoolinvocation.h>
-#include <kicon.h>
+#include <KActionCollection>
+#include <KConfig>
+#include <KIconThemes/KIconLoader>
+#include <KToolBar>
+#include <KToolInvocation>
+#include <KMessageBox>
 
 #include "Options.h"
 #include "kstars.h"
@@ -79,14 +77,11 @@
 #include "skymapgldraw.h"
 #endif
 
-// DEBUG TODO: Remove later -- required to display starhop results for debug.
-#include "skycomponents/targetlistcomponent.h"
-
-#include "starhopper.h"
+#include "starhopperdialog.h"
 
 #ifdef HAVE_XPLANET
 #include <KProcess>
-#include <kfiledialog.h>
+#include <QFileDialog>
 #endif
 
 namespace {
@@ -346,7 +341,7 @@ void SkyMap::slotTransientLabel() {
         if ( so && ! isObjectLabeled( so ) ) {
             QToolTip::showText(
                 QCursor::pos(),
-                i18n("%1: %2<sup>m</sup>",
+                xi18n("%1: %2<sup>m</sup>",
                      so->translatedLongName(),
                      QString::number(so->mag(), 'f', 1)),
                 this);
@@ -366,7 +361,7 @@ void SkyMap::setFocusObject( SkyObject *o ) {
     if ( FocusObject )
         Options::setFocusObject( FocusObject->name() );
     else
-        Options::setFocusObject( i18n( "nothing" ) );
+        Options::setFocusObject( xi18n( "nothing" ) );
 }
 
 void SkyMap::slotCenter() {
@@ -388,10 +383,10 @@ void SkyMap::slotCenter() {
     if ( Options::useAltAz() && Options::showGround() &&
             focus()->alt().Degrees() > -1.0 && focusPoint()->alt().Degrees() < -1.0 ) {
 
-        QString caption = i18n( "Requested Position Below Horizon" );
-        QString message = i18n( "The requested position is below the horizon.\nWould you like to go there anyway?" );
+        QString caption = xi18n( "Requested Position Below Horizon" );
+        QString message = xi18n( "The requested position is below the horizon.\nWould you like to go there anyway?" );
         if ( KMessageBox::warningYesNo( this, message, caption,
-                                        KGuiItem(i18n("Go Anyway")), KGuiItem(i18n("Keep Position")), "dag_focus_below_horiz" )==KMessageBox::No ) {
+                                        KGuiItem(xi18n("Go Anyway")), KGuiItem(xi18n("Keep Position")), "dag_focus_below_horiz" )==KMessageBox::No ) {
             setClickedObject( NULL );
             setFocusObject( NULL );
             Options::setIsTracking( false );
@@ -405,8 +400,8 @@ void SkyMap::slotCenter() {
     setFocusObject( ClickedObject );
     Options::setIsTracking( true );
     if ( kstars ) {
-        kstars->actionCollection()->action("track_object")->setIcon( KIcon("document-encrypt") );
-        kstars->actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
+        kstars->actionCollection()->action("track_object")->setIcon( QIcon::fromTheme("document-encrypt") );
+        kstars->actionCollection()->action("track_object")->setText( xi18n( "Stop &Tracking" ) );
     }
 
     //If focusObject is a SS body and doesn't already have a trail, set the temporaryTrail
@@ -445,12 +440,12 @@ void SkyMap::slotDSS() {
         urlstring = KSUtils::getDSSURL( ra, dec ); // Use default size for non-objects
     }
 
-    KUrl url ( urlstring );
+    QUrl url ( urlstring );
 
     KStars* kstars = KStars::Instance();
     if( kstars ) {
         ImageViewer *iv = new ImageViewer( url,
-            i18n( "Digitized Sky Survey image provided by the Space Telescope Science Institute [public domain]." ),
+            xi18n( "Digitized Sky Survey image provided by the Space Telescope Science Institute [public domain]." ),
             this );
         iv->show();
     }
@@ -481,12 +476,12 @@ void SkyMap::slotSDSS() {
     DecString = DecString.sprintf( "&dec=%f", dec.Degrees() );
 
     //concat all the segments into the kview command line:
-    KUrl url (URLprefix + RAString + DecString + URLsuffix);
+    QUrl url (URLprefix + RAString + DecString + URLsuffix);
 
     KStars* kstars = KStars::Instance();
     if( kstars ) {
         ImageViewer *iv = new ImageViewer( url,
-                                           i18n( "Sloan Digital Sky Survey image provided by the Astrophysical Research Consortium [free for non-commercial use]." ),
+                                           xi18n( "Sloan Digital Sky Survey image provided by the Astrophysical Research Consortium [free for non-commercial use]." ),
                                            this );
         iv->show();
     }
@@ -542,7 +537,7 @@ void SkyMap::slotEndRulerMode() {
         dms angularDistance = AngularRuler.angularSize();
         AngularRuler.clear();
 
-        sbMessage += i18n( "Angular distance: %1", angularDistance.toDMSString() );
+        sbMessage += xi18n( "Angular distance: %1", angularDistance.toDMSString() );
 
         // Create unobsructive message box with suicidal tendencies
         // to display result.
@@ -554,7 +549,7 @@ void SkyMap::slotEndRulerMode() {
         box->show();
     }
     else { // Star Hop
-        StarHopper hopper;
+        StarHopperDialog *shd = new StarHopperDialog( this );
         const SkyPoint &startHop = *AngularRuler.point( 0 );
         const SkyPoint &stopHop = *clickedPoint();
         double fov; // Field of view in arcminutes
@@ -572,32 +567,21 @@ void SkyMap::slotEndRulerMode() {
             foreach( f, data->getVisibleFOVs() ) {
                 nameToFovMap.insert( f->name(), ( ( f->sizeX() >= f->sizeY() && f->sizeY() != 0) ? f->sizeY() : f->sizeX() ) );
             }
-            fov = nameToFovMap[ QInputDialog::getItem( this, i18n("Star Hopper: Choose a field-of-view"), i18n("FOV to use for star hopping:"), nameToFovMap.uniqueKeys(), 0, false, &ok ) ];
+            fov = nameToFovMap[ QInputDialog::getItem( this, xi18n("Star Hopper: Choose a field-of-view"), xi18n("FOV to use for star hopping:"), nameToFovMap.uniqueKeys(), 0, false, &ok ) ];
         }
         else {
             // Ask the user to enter a field of view
-            fov = QInputDialog::getDouble( this, i18n("Star Hopper: Enter field-of-view to use"), i18n("FOV to use for star hopping (in arcminutes):"), 60.0, 1.0, 600.0, 1, &ok );
+            fov = QInputDialog::getDouble( this, xi18n("Star Hopper: Enter field-of-view to use"), xi18n("FOV to use for star hopping (in arcminutes):"), 60.0, 1.0, 600.0, 1, &ok );
         }
 
         Q_ASSERT( fov > 0.0 );
 
         if( ok ) {
 
-            kDebug() << "fov = " << fov;
+            qDebug() << "fov = " << fov;
 
-            QList<const StarObject *> path = hopper.computePath( startHop, stopHop, fov/60.0, 9.0 ); // FIXME: Hardcoded magnitude limits for testing
-
-            QList<SkyObject *> *mutablestarlist = new QList<SkyObject *>(); // FIXME: Memory leak
-            kDebug() << "path count: " << path.count();
-            foreach( const StarObject *conststar, path ) {
-                StarObject *mutablestar = const_cast<StarObject *>(conststar); // FIXME: Ugly const_cast
-                mutablestarlist->append( mutablestar );
-                kDebug() << "Added star!";
-            }
-
-            TargetListComponent *t = KStarsData::Instance()->skyComposite()->getStarHopRouteList();
-            delete t->list;
-            t->list = mutablestarlist;
+            shd->starHop( startHop, stopHop, fov/60.0, 9.0 ); //FIXME: Hardcoded maglimit value
+            shd->show();
         }
 
         rulerMode = false;
@@ -615,8 +599,8 @@ void SkyMap::slotAddFlag() {
 
     // popup FlagManager window and update coordinates
     ks->slotFlagManager();
-    ks->getFlagManager()->clearFields();
-    ks->getFlagManager()->setRaDec( clickedPoint()->ra(), clickedPoint()->dec() );
+    ks->flagManager()->clearFields();
+    ks->flagManager()->setRaDec( clickedPoint()->ra0(), clickedPoint()->dec0() );
 }
 
 void SkyMap::slotEditFlag( int flagIdx ) {
@@ -624,7 +608,7 @@ void SkyMap::slotEditFlag( int flagIdx ) {
 
     // popup FlagManager window and switch to selected flag
     ks->slotFlagManager();
-    ks->getFlagManager()->showFlag( flagIdx );
+    ks->flagManager()->showFlag( flagIdx );
 }
 
 void SkyMap::slotDeleteFlag( int flagIdx ) {
@@ -634,13 +618,13 @@ void SkyMap::slotDeleteFlag( int flagIdx ) {
     ks->data()->skyComposite()->flags()->saveToFile();
 
     // if there is FlagManager created, update its flag model
-    if ( ks->getFlagManager() ) {
-        ks->getFlagManager()->deleteFlagItem( flagIdx );
+    if ( ks->flagManager() ) {
+        ks->flagManager()->deleteFlagItem( flagIdx );
     }
 }
 
 void SkyMap::slotImage() {
-    QString message = ((KAction*)sender())->text();
+    QString message = ((QAction *)sender())->text();
     message = message.remove( '&' ); //Get rid of accelerator markers
 
     // Need to do this because we are comparing translated strings
@@ -656,20 +640,20 @@ void SkyMap::slotImage() {
     if ( index >= 0 && index < clickedObject()->ImageList().size() ) {
         sURL = clickedObject()->ImageList()[ index ];
     } else {
-        kWarning() << "ImageList index out of bounds: " << index;
+        qWarning() << "ImageList index out of bounds: " << index;
         if ( index == -1 ) {
-            kWarning() << "Message string \"" << message << "\" not found in ImageTitle.";
-            kDebug() << clickedObject()->ImageTitle();
+            qWarning() << "Message string \"" << message << "\" not found in ImageTitle.";
+            qDebug() << clickedObject()->ImageTitle();
         }
     }
 
-    KUrl url ( sURL );
+    QUrl url ( sURL );
     if( !url.isEmpty() )
         new ImageViewer( url, clickedObject()->messageFromTitle(message), this );
 }
 
 void SkyMap::slotInfo() {
-    QString message = ((KAction*)sender())->text();
+    QString message = ((QAction *)sender())->text();
     message = message.remove( '&' ); //Get rid of accelerator markers
 
     // Need to do this because we are comparing translated strings
@@ -685,16 +669,16 @@ void SkyMap::slotInfo() {
     if ( index >= 0 && index < clickedObject()->InfoList().size() ) {
         sURL = clickedObject()->InfoList()[ index ];
     } else {
-        kWarning() << "InfoList index out of bounds: " << index;
+        qWarning() << "InfoList index out of bounds: " << index;
         if ( index == -1 ) {
-            kWarning() << "Message string \"" << message << "\" not found in InfoTitle.";
-            kDebug() << clickedObject()->InfoTitle();
+            qWarning() << "Message string \"" << message << "\" not found in InfoTitle.";
+            qDebug() << clickedObject()->InfoTitle();
         }
     }
 
-    KUrl url ( sURL );
+    QUrl url ( sURL );
     if (!url.isEmpty())
-        KToolInvocation::invokeBrowser(sURL);
+        QDesktopServices::openUrl(sURL);
 }
 
 bool SkyMap::isObjectLabeled( SkyObject *object ) {
@@ -739,7 +723,7 @@ void SkyMap::slotAddPlanetTrail() {
 void SkyMap::slotDetail() {
     // check if object is selected
     if ( !clickedObject() ) {
-        KMessageBox::sorry( this, i18n("No object selected."), i18n("Object Details") );
+        KMessageBox::sorry( this, xi18n("No object selected."), xi18n("Object Details") );
         return;
     }
     DetailDialog* detail = new DetailDialog( clickedObject(), data->ut(), data->geo(), KStars::Instance() );
@@ -748,8 +732,8 @@ void SkyMap::slotDetail() {
 }
 
 void SkyMap::slotObjectSelected() {
-    if(m_objPointingMode && KStars::Instance()->getPrintingWizard()) {
-        KStars::Instance()->getPrintingWizard()->pointingDone(clickedObject());
+    if(m_objPointingMode && KStars::Instance()->printingWizard()) {
+        KStars::Instance()->printingWizard()->pointingDone(clickedObject());
         m_objPointingMode = false;
     }
 }
@@ -761,15 +745,15 @@ void SkyMap::slotCancelLegendPreviewMode() {
 }
 
 void SkyMap::slotFinishFovCaptureMode() {
-    if(m_fovCaptureMode && KStars::Instance()->getPrintingWizard()) {
-        KStars::Instance()->getPrintingWizard()->fovCaptureDone();
+    if(m_fovCaptureMode && KStars::Instance()->printingWizard()) {
+        KStars::Instance()->printingWizard()->fovCaptureDone();
         m_fovCaptureMode = false;
     }
 }
 
 void SkyMap::slotCaptureFov() {
-    if(KStars::Instance()->getPrintingWizard()) {
-        KStars::Instance()->getPrintingWizard()->captureFov();
+    if(KStars::Instance()->printingWizard()) {
+        KStars::Instance()->printingWizard()->captureFov();
     }
 }
 
@@ -893,7 +877,7 @@ void SkyMap::slewFocus() {
             double r  = r0;
             while ( r > step ) {
                 //DEBUG
-                kDebug() << step << ": " << r << ": " << r0 << endl;
+                qDebug() << step << ": " << r << ": " << r0 << endl;
                 double fX = dX / r;
                 double fY = dY / r;
 
@@ -1094,29 +1078,29 @@ void SkyMap::slotToggleGL() {
         // Do NOT use GL
         Options::setUseGL( false );
         m_SkyMapDraw = m_SkyMapQDraw;
-        KStars::Instance()->actionCollection()->action( "opengl" )->setText(i18n("Switch to OpenGL backend"));
+        KStars::Instance()->actionCollection()->action( "opengl" )->setText(xi18n("Switch to OpenGL backend"));
     }
     else {
         // Use GL
-        QString message = i18n("This version of KStars comes with new experimental OpenGL support. Our experience is that OpenGL works "
+        QString message = xi18n("This version of KStars comes with new experimental OpenGL support. Our experience is that OpenGL works "
                                "much faster on machines with hardware acceleration. Would you like to switch to OpenGL painting backends?");
 
         int result = KMessageBox::warningYesNo( this, message,
-                                                i18n("Switch to OpenGL backend"),
+                                                xi18n("Switch to OpenGL backend"),
                                                 KStandardGuiItem::yes(),
                                                 KStandardGuiItem::no(),
                                                 "dag_opengl_switch" );
 
         if ( result == KMessageBox::Yes ) {
 
-            KMessageBox::information( this, i18n("Infoboxes will be disabled as they do not work correctly when using OpenGL backends as of this version"),
-                                      i18n("Switch to OpenGL backend"),
+            KMessageBox::information( this, xi18n("Infoboxes will be disabled as they do not work correctly when using OpenGL backends as of this version"),
+                                      xi18n("Switch to OpenGL backend"),
                                       "dag_opengl_infoboxes" );
 
             Options::setUseGL( true );
 
             m_SkyMapDraw = m_SkyMapGLDraw;
-            KStars::Instance()->actionCollection()->action( "opengl" )->setText(i18n("Switch to QPainter backend"));
+            KStars::Instance()->actionCollection()->action( "opengl" )->setText(xi18n("Switch to QPainter backend"));
         }
     }
     m_SkyMapDraw->setParent( viewport() );
@@ -1131,7 +1115,7 @@ void SkyMap::startXplanet( const QString & outputFile ) {
 
     // If Options::xplanetPath() is empty, return
     if ( Options::xplanetPath().isEmpty() ) {
-        KMessageBox::error(0, i18n("Xplanet binary path is empty in config panel."));
+        KMessageBox::error(0, xi18n("Xplanet binary path is empty in config panel."));
         return;
     }
 
@@ -1236,7 +1220,7 @@ void SkyMap::startXplanet( const QString & outputFile ) {
     *xplanetProc << "-origin" << "earth";
 
     // Run xplanet
-    kDebug() << "Run:" << xplanetProc->program().join(" ");
+    qDebug() << "Run:" << xplanetProc->program().join(" ");
     xplanetProc->start();
 }
 
@@ -1245,11 +1229,11 @@ void SkyMap::slotXplanetToScreen() {
 }
 
 void SkyMap::slotXplanetToFile() {
-    QString filename = KFileDialog::getSaveFileName( );
+    QString filename = QFileDialog::getSaveFileName( );
     if ( ! filename.isEmpty() ) {
         startXplanet( filename );
     }
 }
 #endif
 
-#include "skymap.moc"
+
