@@ -25,10 +25,10 @@
 JupiterMoons::JupiterMoons(){
     //Initialize the Moon objects.  The magnitude data are from the 
     //wikipedia articles for each moon, as of Oct 2007.
-    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 5.0, i18nc( "Jupiter's moon Io", "Io" ) ) );
-    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 5.3, i18nc( "Jupiter's moon Europa", "Europa" ) ) );
-    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 4.6, i18nc( "Jupiter's moon Ganymede", "Ganymede" ) ) );
-    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 5.7, i18nc( "Jupiter's moon Callisto", "Callisto" ) ) );
+    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 5.0, xi18nc( "Jupiter's moon Io", "Io" ) ) );
+    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 5.3, xi18nc( "Jupiter's moon Europa", "Europa" ) ) );
+    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 4.6, xi18nc( "Jupiter's moon Ganymede", "Ganymede" ) ) );
+    Moon.append( new TrailObject( SkyObject::MOON, 0.0, 0.0, 5.7, xi18nc( "Jupiter's moon Callisto", "Callisto" ) ) );
 
     XP = QVector<double>(4, 0.0);
     YP = QVector<double>(4, 0.0);
@@ -460,9 +460,9 @@ void JupiterMoons::findPosition( const KSNumbers *num, const KSPlanetBase *Jupit
         C6[i] = C5[i] * cos( ALPHA ) - B5[i] * sin( ALPHA );
 
         /* DEBUG
-        kDebug() <<"A: "<<i<<": "<<A1[i]<<": "<<A2[i]<<": "<<A3[i]<<": "<<A4[i]<<": "<<A5[i]<<": "<<A6[i];
-        kDebug() <<"B: "<<i<<": "<<B1[i]<<": "<<B2[i]<<": "<<B3[i]<<": "<<B4[i]<<": "<<B5[i]<<": "<<B6[i];
-        kDebug() <<"C: "<<i<<": "<<C1[i]<<": "<<C2[i]<<": "<<C3[i]<<": "<<C4[i]<<": "<<C5[i]<<": "<<C6[i];
+        qDebug() <<"A: "<<i<<": "<<A1[i]<<": "<<A2[i]<<": "<<A3[i]<<": "<<A4[i]<<": "<<A5[i]<<": "<<A6[i];
+        qDebug() <<"B: "<<i<<": "<<B1[i]<<": "<<B2[i]<<": "<<B3[i]<<": "<<B4[i]<<": "<<B5[i]<<": "<<B6[i];
+        qDebug() <<"C: "<<i<<": "<<C1[i]<<": "<<C2[i]<<": "<<C3[i]<<": "<<C4[i]<<": "<<C5[i]<<": "<<C6[i];
         */
     }
 
@@ -482,6 +482,10 @@ void JupiterMoons::findPosition( const KSNumbers *num, const KSPlanetBase *Jupit
         Moon[i]->setRA( Jupiter->ra().Hours() - 0.011*( XP[i] * cos( pa ) - YP[i] * sin( pa ) )/15.0 );
         Moon[i]->setDec( Jupiter->dec().Degrees() - 0.011*( XP[i] * sin( pa ) + YP[i] * cos( pa ) ) );
 
+        SkyPoint p = Moon[i]->deprecess( num ); // FIXME: Really, we should also denutate. Actually, we should also be aberrating these above, right?
+        Moon[i]->setRA0( p.ra() ); // Just to be sure, in case deprecess doesn't set it already because RA0 was not NaN or something.
+        Moon[i]->setDec0( p.dec() );
+
         if ( ZP[i] < 0.0 ) InFront[i] = true;
         else InFront[i] = false;
 
