@@ -82,9 +82,9 @@ KSPlanetBase* KSPlanetBase::createPlanet( int n ) {
         case KSPlanetBase::NEPTUNE:
             return new KSPlanet( n );
             break;
-        case KSPlanetBase::PLUTO:
+        /*case KSPlanetBase::PLUTO:
             return new KSPluto();
-            break;
+            break;*/
         case KSPlanetBase::SUN:
             return new KSSun();
             break;
@@ -130,7 +130,7 @@ void KSPlanetBase::findPosition( const KSNumbers *num, const dms *lat, const dms
         localizeCoords( num, lat, LST ); //correct for figure-of-the-Earth
 
     if ( hasTrail() ) {
-        addToTrail();
+        addToTrail( KStarsDateTime( num->getJD() ).toString( "yyyy.MM.dd hh:mm" ) + xi18nc("Universal time", "UT") ); // TODO: Localize date/time format?
         if ( Trail.size() > TrailObject::MaxTrail )
             clipTrail();
     }
@@ -142,17 +142,17 @@ void KSPlanetBase::findPosition( const KSNumbers *num, const dms *lat, const dms
         KSComet *me = (KSComet *)this;
         double TailAngSize;
         // Convert the tail size in km to angular tail size (degrees)
-        TailAngSize = asin(physicalSize()/Rearth/AU_KM)*60.0*180.0/dms::PI; 
+        TailAngSize = asin(physicalSize()/Rearth/AU_KM)*60.0*180.0/dms::PI;
         // Find the apparent length as projected on the celestial sphere (the comet's tail points away from the sun)
-        me->setTailAngSize( TailAngSize * fabs(sin( phase().radians() ))); 
+        me->setTailAngSize( TailAngSize * fabs(sin( phase().radians() )));
     }
 
 }
 
 bool KSPlanetBase::isMajorPlanet() const {
-    if ( name() == i18n( "Mercury" ) || name() == i18n( "Venus" ) || name() == i18n( "Mars" ) ||
-         name() == i18n( "Jupiter" ) || name() == i18n( "Saturn" ) || name() == i18n( "Uranus" ) ||
-         name() == i18n( "Neptune" ) )
+    if ( name() == xi18n( "Mercury" ) || name() == xi18n( "Venus" ) || name() == xi18n( "Mars" ) ||
+         name() == xi18n( "Jupiter" ) || name() == xi18n( "Saturn" ) || name() == xi18n( "Uranus" ) ||
+         name() == xi18n( "Neptune" ) )
         return true;
     return false;
 }
@@ -215,7 +215,7 @@ void KSPlanetBase::setRearth( const KSPlanetBase *Earth ) {
     }
 
     if ( ! Earth  ) {
-        kDebug() << i18n( "KSPlanetBase::setRearth():  Error: Need an Earth pointer.  (" ) << name() << ")";
+        qDebug() << xi18n( "KSPlanetBase::setRearth():  Error: Need an Earth pointer.  (" ) << name() << ")";
         Rearth = 1.0;
         return;
     }
@@ -269,7 +269,7 @@ double KSPlanetBase::labelOffset() const {
         size = minsize;
 
     //Inflate offset for Saturn
-    if ( name() == i18n( "Saturn" ) )
+    if ( name() == xi18n( "Saturn" ) )
         size = int(2.5*size);
 
     return 0.5*size + 4.;
