@@ -16,13 +16,11 @@
  ***************************************************************************/
 
 #include "modcalcangdist.h"
-#include "modcalcangdist.moc"
 
 #include <QTextStream>
 
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include "dms.h"
 #include "widgets/dmsbox.h"
@@ -95,11 +93,11 @@ void modCalcAngDist::slotObjectButton() {
         if ( sender()->objectName() == QString("FirstObjectButton") ) {
             FirstRA->showInHours( o->ra() );
             FirstDec->showInDegrees( o->dec() );
-            FirstPositionBox->setTitle( i18n("First position: %1", o->name()) );
+            FirstPositionBox->setTitle( xi18n("First position: %1", o->name()) );
         } else {
             SecondRA->showInHours( o->ra() );
             SecondDec->showInDegrees( o->dec() );
-            SecondPositionBox->setTitle( i18n("Second position: %1", o->name()) );
+            SecondPositionBox->setTitle( xi18n("Second position: %1", o->name()) );
         }
 
         slotValidatePositions();
@@ -110,9 +108,9 @@ void modCalcAngDist::slotObjectButton() {
 void modCalcAngDist::slotResetTitle() {
     QString name = sender()->objectName();
     if ( name.contains( "First" ) )
-        FirstPositionBox->setTitle( i18n("First position") );
+        FirstPositionBox->setTitle( xi18n("First position") );
     else
-        SecondPositionBox->setTitle( i18n("Second position") );
+        SecondPositionBox->setTitle( xi18n("Second position") );
 }
 
 void modCalcAngDist::slotRunBatch() {
@@ -124,8 +122,8 @@ void modCalcAngDist::slotRunBatch() {
     if ( QFile::exists(inputFileName) ) {
         QFile f( inputFileName );
         if ( !f.open( QIODevice::ReadOnly) ) {
-            QString message = i18n( "Could not open file %1.", f.fileName() );
-            KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
+            QString message = xi18n( "Could not open file %1.", f.fileName() );
+            KMessageBox::sorry( 0, message, xi18n( "Could Not Open File" ) );
             inputFileName.clear();
             return;
         }
@@ -136,8 +134,8 @@ void modCalcAngDist::slotRunBatch() {
         //		readFile( istream );
         f.close();
     } else  {
-        QString message = i18n( "Invalid file: %1", inputFileName );
-        KMessageBox::sorry( 0, message, i18n( "Invalid file" ) );
+        QString message = xi18n( "Invalid file: %1", inputFileName );
+        KMessageBox::sorry( 0, message, xi18n( "Invalid file" ) );
         inputFileName.clear();
         InputLineEditBatch->setText( inputFileName );
         return;
