@@ -18,10 +18,10 @@
 #include "modcalcgeodcoord.h"
 
 #include <QTextStream>
+#include <QFileDialog>
 
-#include <kfiledialog.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <KMessageBox>
+#include <KLocalizedString>
 
 #include "dms.h"
 #include "geolocation.h"
@@ -71,9 +71,9 @@ void modCalcGeodCoord::setEllipsoid(int index) {
 void modCalcGeodCoord::getCartGeoCoords (void)
 {
 
-    geoPlace->setXPos( KGlobal::locale()->readNumber(XGeoBox->text())*1000. );
-    geoPlace->setYPos( KGlobal::locale()->readNumber(YGeoBox->text())*1000. );
-    geoPlace->setZPos( KGlobal::locale()->readNumber(ZGeoBox->text())*1000. );
+    geoPlace->setXPos( XGeoBox->text().toDouble()*1000. );
+    geoPlace->setYPos( YGeoBox->text().toDouble()*1000. );
+    geoPlace->setZPos( ZGeoBox->text().toDouble()*1000. );
 }
 
 void modCalcGeodCoord::getSphGeoCoords (void)
@@ -110,15 +110,15 @@ void modCalcGeodCoord::showSpheGeoCoords(void)
 {
     LongGeoBox->show( geoPlace->lng() );
     LatGeoBox->show( geoPlace->lat() );
-    AltGeoBox->setText( KGlobal::locale()->formatNumber( geoPlace->height(), 3) );
+    AltGeoBox->setText( QLocale().toString( geoPlace->height(), 3) );
 }
 
 void modCalcGeodCoord::showCartGeoCoords(void)
 {
 
-    XGeoBox->setText( KGlobal::locale()->formatNumber( geoPlace->xPos()/1000. ,6));
-    YGeoBox->setText( KGlobal::locale()->formatNumber( geoPlace->yPos()/1000. ,6));
-    ZGeoBox->setText( KGlobal::locale()->formatNumber( geoPlace->zPos()/1000. ,6));
+    XGeoBox->setText( QLocale().toString( geoPlace->xPos()/1000. ,6));
+    YGeoBox->setText( QLocale().toString( geoPlace->yPos()/1000. ,6));
+    ZGeoBox->setText( QLocale().toString( geoPlace->zPos()/1000. ,6));
 }
 
 void modCalcGeodCoord::geoCheck(void) {
@@ -206,14 +206,14 @@ void modCalcGeodCoord::slotZCheckedBatch(){
 void modCalcGeodCoord::slotInputFile() {
 
     QString inputFileName;
-    inputFileName = KFileDialog::getOpenFileName( );
+    inputFileName = QFileDialog::getOpenFileName(0, QString(),  QString());
     InputFileBoxBatch->setUrl( inputFileName );
 }
 
 void modCalcGeodCoord::slotOutputFile() {
 
     QString outputFileName;
-    outputFileName = KFileDialog::getSaveFileName( );
+    outputFileName = QFileDialog::getSaveFileName();
     OutputFileBoxBatch->setUrl( outputFileName );
 }
 
@@ -228,8 +228,8 @@ void modCalcGeodCoord::slotRunBatch(void) {
     if ( QFile::exists(inputFileName) ) {
         QFile f( inputFileName );
         if ( !f.open( QIODevice::ReadOnly) ) {
-            QString message = i18n( "Could not open file %1.", f.fileName() );
-            KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
+            QString message = xi18n( "Could not open file %1.", f.fileName() );
+            KMessageBox::sorry( 0, message, xi18n( "Could Not Open File" ) );
             inputFileName.clear();
             return;
         }
@@ -240,8 +240,8 @@ void modCalcGeodCoord::slotRunBatch(void) {
         //		readFile( istream );
         f.close();
     } else  {
-        QString message = i18n( "Invalid file: %1", inputFileName );
-        KMessageBox::sorry( 0, message, i18n( "Invalid file" ) );
+        QString message = xi18n( "Invalid file: %1", inputFileName );
+        KMessageBox::sorry( 0, message, xi18n( "Invalid file" ) );
         inputFileName.clear();
         InputFileBoxBatch->setUrl( inputFileName );
         return;
@@ -289,7 +289,7 @@ void modCalcGeodCoord::processLines( QTextStream &istream ) {
                 xB = fields[i].toDouble();
                 i++;
             } else
-                xB = KGlobal::locale()->readNumber(XGeoBoxBatch->text()) ;
+                xB = XGeoBoxBatch->text().toDouble() ;
 
             if ( AllRadioBatch->isChecked() )
                 ostream << xB << space;
@@ -303,7 +303,7 @@ void modCalcGeodCoord::processLines( QTextStream &istream ) {
                 yB = fields[i].toDouble();
                 i++;
             } else
-                yB = KGlobal::locale()->readNumber( YGeoBoxBatch->text()) ;
+                yB = YGeoBoxBatch->text().toDouble() ;
 
             if ( AllRadioBatch->isChecked() )
                 ostream << yB << space;
@@ -316,7 +316,7 @@ void modCalcGeodCoord::processLines( QTextStream &istream ) {
                 zB = fields[i].toDouble();
                 i++;
             } else
-                zB = KGlobal::locale()->readNumber( ZGeoBoxBatch->text());
+                zB = ZGeoBoxBatch->text().toDouble();
 
             if ( AllRadioBatch->isChecked() )
                 ostream << zB << space;
@@ -393,4 +393,3 @@ void modCalcGeodCoord::processLines( QTextStream &istream ) {
     fOut.close();
 }
 
-#include "modcalcgeodcoord.moc"
