@@ -16,14 +16,14 @@
  ***************************************************************************/
 
 #include "timeunitbox.h"
-#include "timeunitbox.moc"
+
 
 #include <cstdlib>
 
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <kdebug.h>
+#include <QDebug>
 
 static const char * const up_arrow[] = {
 "22 11 4 1",
